/******************************************************************************

Exp1BuildAnalysis.do

This file runs the data cleaning and analysis for experiment 1.

*******************************************************************************/

** Config%<
global gpr = "plotregion(fcolor(white) lcolor(white) m(tiny)) graphregion(fcolor(white) lcolor(white))"

** Data build%<

cap program drop clean_main_dset/*%<*/
program define clean_main_dset
    # delimit ;
    use "$rawdata/Experiment 1/all_subjects_raw.dta", clear;
    merge campus_ID ID using "$rawdata/Experiment 1/all_onboarding.dta", _merge(onb);
    tab onb;
    keep if onb~=2;
    gen idnum=ID;
	
	encode gender, gen(gendercode);
	replace gendercode = 3 if gendercode == 4;
	replace gendercode = . if gendercode > 3;
	label define gender 1 "Female" 2 "Male" 3 "Non-binary or prefer not to answer", replace;
	label values gendercode gender;
	drop gender;
	rename gendercode gender;
	
    la var anyneg "FLAG: Any negative time recorded in CA data (error)";
    la var cyear "class/graduation year";
    la var gender "gender";
    la var perc_complete "% expect to complete";
    la var perc_complete_plan "% expect to complete if make a plan";
    la var perc_complete_2 "% expect to complete if $2 reward";
    la var perc_complete_5 "% expect to complte if $5 reward";
    la var predict "was asked prediction survey questions";

    keep idnum ID ical google alum stud group anyneg g1-g6 c1-c6 campus_ID time_w1 time_w2 time_w3 time_w4 time_w5 time_w6 time_w7 time_w8
    time_w1_recode time_w2_recode time_w3_recode time_w4_recode time_w5_recode time_w6_recode time_w7_recode time_w8_recode
    plan1 plan2 plan3 plan4 plan5 plan6 plan7 plan8 task1 task2 task3 task4 task5 task6 task7 task8
    task_R451 task_R452 task_R453 task_R454 task_R455 task_R456 task_R457 task_R458 opened_w1 opened_w2 opened_w3 opened_w4 opened_w5 opened_w6 opened_w7 opened_w8
    task_R401 task_R402 task_R403 task_R404 task_R405 task_R406 task_R407 task_R408 gender cyear 
    perc_complete perc_complete_plan perc_complete_2 perc_complete_5
    predict;

    save "$preppeddata/Experiment 1/all_subjects_workingdata_20190806.dta", replace;
	# delimit cr;
end/*%>*/

cap program drop create_reshape_data_20190815/*%<*/
program define create_reshape_data_20190815

    use "$preppeddata/Experiment 1/all_subjects_workingdata_20190806", clear
    egen camp_group = group(campus_ID)
	local survars usedlink otherplans plan_help helpful_reminder ///
	    helpful_blocktime course_expect course_diffic
	reshape long time_w plan task task_R45 task_R40 opened_w, ///
	    i(idnum) j(week)

    gen plan_missing_temp = (missing(plan))
	egen plan_missing_fin = max(plan_missing_temp), by(idnum)
	drop plan_missing_temp
	gen time_w_ckw = time_w
	    replace time_w_ckw=. if time_w_ckw>=600
	gen missing = (missing(time_w_ckw) | anyneg==1)
	egen missing_fin = max(missing), by(idnum)
	drop missing

	foreach num in 0 10 20 30 40 45 50 60 {
	    gen task_R`num'_ckw = (time_w_ckw>`num' & !missing(time_w_ckw)) 
	}
	
	gen dollar_task = 2 if g1==1
	   replace dollar_task = 5 if g2==1
	   replace dollar_task = 0 if group==6 | missing(dollar_task)
	   
	gen dollar_plan = 1 if g3==1
	    replace dollar_plan=2 if g4==1
		replace dollar_plan=0 if group==6 | missing(dollar_plan)
		
	gen plan_sample = (g3==1 | g4==1 | group==6)
	gen task_sample = (g1==1 | g2==1 | group==6)    
	save "$preppeddata/Experiment 1/all_subjects_reshape_20190815", replace

end/*%>*/

capture program drop participant_characteristics/*%<*/
program define participant_characteristics
	use "$preppeddata/Experiment 1/all_subjects_workingdata_20190806", clear
	count if stud == 1
	latex_write \studentN `r(N)'
	
	count if stud == 0
	latex_write \alumniN `r(N)'
	
	// Current students
	foreach year in 2018 2019 2020 2021 {
		if `year' == 2018 local name "senior"
		if `year' == 2019 local name "junior"
		if `year' == 2020 local name "soph"
		if `year' == 2021 local name "\first"
		
		di "`name'"
		
		sum `year'.cyear if stud == 1
		local prop: di %3.2f r(mean)
		local SD: di %3.2f r(sd)

		** Write to Latex
		latex_write `name' "`prop'"
		latex_write `name'SD "`SD'"
	}
	
	// Alumni
	foreach year in 2013 2014 2015 2016 2017 {
		if `year' == 2013 local name "XIII"
		if `year' == 2014 local name "XIV"
		if `year' == 2015 local name "XV"
		if `year' == 2016 local name "XVI"
		if `year' == 2017 local name "XVII"
		
		sum `year'.cyear if stud == 0
		local prop: di %3.2f r(mean)
		local SD: di %3.2f r(sd)

		** Write to Latex
		latex_write `name' "`prop'"
		latex_write `name'SD "`SD'"
	}
	
	// Gender
	foreach student in 0 1 {
		if `student' == 0 local stud "\a" // alumni
		if `student' == 1 local stud "\s" // student
	
		foreach g in 1 2 3 {
			if `g' == 1 local name "Fem"
			if `g' == 2 local name "Male"
			if `g' == 3 local name "NB"
			
			sum `g'.gender if stud == `student'
			
			local prop: di %3.2f r(mean)
			local SD: di %3.2f r(sd)

			** Write to Latex
			latex_write `stud'`name' "`prop'"
			latex_write `stud'`name'SD "`SD'"
		}
	}
end/*%>*/
	
capture program drop make_cross_section/*%<*/
program define make_cross_section

    use "$preppeddata/Experiment 1/all_subjects_reshape_20190815", clear
    
    if ("`1'" != "keep5") {
        drop if group == 5
    }

    forv i = 1/8 {
        egen plan_week`i'_temp = mean(plan) if week==`i', by(idnum)
        egen plan_week`i' = max(plan_week`i'_temp), by(idnum)
        drop plan_week`i'_temp
    }
	
	egen plan_week14_temp = mean(plan) if inrange(week,1,4), by(idnum)
	egen plan_week14 = max(plan_week14_temp), by(idnum)
	drop plan_week14_temp
	
	egen plan_week18_temp = mean(plan) if inrange(week,1,8), by(idnum)
	egen plan_week18 = max(plan_week18_temp), by(idnum)
	drop plan_week18_temp

    foreach num in 0 10 20 30 40 45 50 60 {
        forv i = 1/8 {
            egen task_R`num'_week`i'_temp = mean(task_R`num'_ckw) if week==`i', by(idnum)    
            egen task_R`num'_week`i' = max(task_R`num'_week`i'_temp), by(idnum)    
            drop task_R`num'_week`i'_temp
        }

        egen task_R`num'_week14_temp = mean(task_R`num'_ckw) if inrange(week,1,4), by(idnum)    
        egen task_R`num'_week14 = max(task_R`num'_week14_temp), by(idnum)    
        drop task_R`num'_week14_temp

        egen task_R`num'_week18_temp = mean(task_R`num'_ckw) if inrange(week,1,8), by(idnum)    
        egen task_R`num'_week18 = max(task_R`num'_week18_temp), by(idnum)    
        drop task_R`num'_week18_temp
    }

    egen combined_group = group(alum ical camp_group)
	
	/* Collapse to one obs. per idnum */
	collapse (max) camp_group alum ical combined_group plan_sample task_sample ///
	    plan_week* task_R*_week* ///
		g1 g2 g3 g4 group dollar_plan dollar_task, by(idnum)


end/*%>*/

capture program drop make_panel/*%<*/
program define make_panel

    use "$preppeddata/Experiment 1/all_subjects_reshape_20190815", clear
    
    if ("`1'" != "keep5") {
        drop if group == 5
    }

    forv i = 1/8 {
        egen plan_week`i'_temp = mean(plan) if week==`i', by(idnum)
        egen plan_week`i' = max(plan_week`i'_temp), by(idnum)
        drop plan_week`i'_temp
    }

    egen combined_group = group(alum ical camp_group)
    
end/*%>*/

capture program drop table_planning_20190828/*%<*/
program define table_planning_20190828

    make_cross_section
    
	reg plan_week1 dollar_plan i.combined_group if plan_sample==1
    local beta1: di %05.3f = _b[dollar_plan]
	local se1: di %05.3f = _se[dollar_plan]
	local N1: di %5.0f = e(N)
	local R1: di %05.3f = e(r2)
	local t = _b[dollar_plan]/_se[dollar_plan]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars "***"
	else if `p'<0.05 local stars "**"
	else if `p'<0.1 local stars "*"
	else local stars " "
	di `se1'
	summ plan_week1 if e(sample)==1 & group==6
	local mean1: di %05.3f = r(mean)
	di `mean1'
	
	reg plan_week14 dollar_plan i.combined_group if plan_sample==1
    local beta2: di %05.3f = _b[dollar_plan]
	local se2: di %05.3f = _se[dollar_plan]
	local N2: di %5.0f = e(N)
	local R2: di %05.3f = e(r2)
	local t = _b[dollar_plan]/_se[dollar_plan]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'    
	if `p'<0.01 local stars2 "***"
	else if `p'<0.05 local stars2 "**"
	else if `p'<0.1 local stars2 "*"
	else local stars2 " "
	di `se2'
	summ plan_week14 if e(sample)==1 & group==6
	local mean2: di %05.3f = r(mean)
	di `mean2'
	
	reg plan_week18 dollar_plan i.combined_group if plan_sample==1
    local beta3: di %05.3f = _b[dollar_plan]
	local se3: di %05.3f = _se[dollar_plan]
	local N3: di %5.0f = e(N)
	local R3: di %05.3f = e(r2)
	local t = _b[dollar_plan]/_se[dollar_plan]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'    
    if `p'<0.01 local stars3 "***"
	else if `p'<0.05 local stars3 "**"
	else if `p'<0.1 local stars3 "*"
	else local stars3 " "
	di `se3'
	summ plan_week18 if e(sample)==1 & group==6
	local mean3: di %05.3f = r(mean)
	di `mean3'
	
    cap file close table_plan
	file open table_plan using "$tables/Experiment 1/table_plan_20190828.tex", write replace
	file write table_plan "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" _n
	file write table_plan "\begin{tabular}{l*{4}{c}}" _n
	file write table_plan "\multicolumn{3}{l}{Panel A: The Effect on Plan Making (First Stage)} \\" _n
	file write table_plan "\midrule" _n 
	file write table_plan "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)} \\" _n
    file write table_plan "&\multicolumn{1}{c}{Week 1}&\multicolumn{1}{c}{Weeks 1-4}" _n
	file write table_plan "&\multicolumn{1}{c}{Weeks 1-8} \\"	_n
	file write table_plan "\midrule" _n
    file write table_plan "Plan Incentive & `beta1'`stars' & `beta2'`stars2' & `beta3'`stars3' \\" _n
	file write table_plan "& (`se1') & (`se2') & (`se3') \\" _n
    file write table_plan "\midrule" _n
	file write table_plan "Obs. & `N1' & `N2' & `N3' \\" _n
    file write table_plan "R\textsuperscript{2} & `R1' & `R2' & `R3' \\" _n	
	file write table_plan "Control Mean & `mean1' & `mean2' & `mean3' \\" _n
	file write table_plan "Controls & Yes & Yes & Yes \\" _n
	file write table_plan "Campus FE & Yes & Yes & Yes \\" _n	
	file write table_plan "\midrule" _n
	file write table_plan "& & & \\" _n
	file write table_plan "\end{tabular}" _n
	
    reg task_R20_week1 dollar_plan i.combined_group if plan_sample==1
    local beta4: di %05.3f = _b[dollar_plan]
	local se4: di %05.3f = _se[dollar_plan]
	local N4: di %5.0f = e(N)
	local R4: di %05.3f = e(r2)
	local t = _b[dollar_plan]/_se[dollar_plan]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars4 "***"
	else if `p'<0.05 local stars4 "**"
	else if `p'<0.1 local stars4 "*"
	else local stars4 " "
	di `se4'
	summ task_R20_week1 if e(sample)==1 & group==6
	local mean4: di %05.3f = r(mean)
	di `mean4'
	
    reg task_R20_week14 dollar_plan i.combined_group if plan_sample==1
    local beta5: di %05.3f = _b[dollar_plan]
	local se5: di %05.3f = _se[dollar_plan]
	local N5: di %5.0f = e(N)
	local R5: di %05.3f = e(r2)
    local t = _b[dollar_plan]/_se[dollar_plan]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars5 "***"
	else if `p'<0.05 local stars5 "**"
	else if `p'<0.1 local stars5 "*"
	else local stars5 " "
	di `se5'
	summ task_R20_week14 if e(sample)==1 & group==6
	local mean5: di %05.3f = r(mean)
	di `mean5'
	
    reg task_R20_week18 dollar_plan i.combined_group if plan_sample==1
    local beta6: di %05.3f = _b[dollar_plan]
	local se6: di %05.3f = _se[dollar_plan]
	local N6: di %5.0f = e(N)
	local R6: di %05.3f = e(r2)
    local t = _b[dollar_plan]/_se[dollar_plan]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars6 "***"
	else if `p'<0.05 local stars6 "**"
	else if `p'<0.1 local stars6 "*"
	else local stars6 " "
	di `se6'
	summ task_R20_week18 if e(sample)==1 & group==6
	local mean6: di %05.3f = r(mean)
	di `mean6'
	
    reg task_R45_week1 dollar_plan i.combined_group if plan_sample==1
    local beta7: di %05.3f = _b[dollar_plan]
	local se7: di %05.3f = _se[dollar_plan]
	local N7: di %5.0f = e(N)
	local R7: di %05.3f = e(r2)
    local t = _b[dollar_plan]/_se[dollar_plan]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars7 "***"
	else if `p'<0.05 local stars7 "**"
	else if `p'<0.1 local stars7 "*"
	else local stars7 " "
	di `se7'
	summ task_R45_week1 if e(sample)==1 & group==6
	local mean7: di %05.3f = r(mean)
	di `mean7'
	
    reg task_R45_week14 dollar_plan i.combined_group if plan_sample==1
    local beta8: di %05.3f = _b[dollar_plan]
	local se8: di %05.3f = _se[dollar_plan]
	local N8: di %5.0f = e(N)
	local R8: di %05.3f = e(r2)
    local t = _b[dollar_plan]/_se[dollar_plan]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars8 "***"
	else if `p'<0.05 local stars8 "**"
	else if `p'<0.1 local stars8 "*"
	else local stars8 " "
	di `se8'
	summ task_R45_week14 if e(sample)==1 & group==6
	local mean8: di %05.3f = r(mean)
	di `mean8'
	
    reg task_R45_week18 dollar_plan i.combined_group if plan_sample==1
    local beta9: di %05.3f = _b[dollar_plan]
	local se9: di %05.3f = _se[dollar_plan]
	local N9: di %5.0f = e(N)
	local R9: di %05.3f = e(r2)
    local t = _b[dollar_plan]/_se[dollar_plan]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars9 "***"
	else if `p'<0.05 local stars9 "**"
	else if `p'<0.1 local stars9 "*"
	else local stars9 " "
	di `se9'
	summ task_R45_week18 if e(sample)==1 & group==6
	local mean9: di %05.3f = r(mean)
	di `mean9'

    file write table_plan "\begin{tabular}{l*{7}{c}}" _n
	file write table_plan "\multicolumn{7}{l}{Panel B: The Effect on Coding Task Completion (Reduced Form)} \\" _n
	file write table_plan "\midrule" _n 
	
    file write table_plan "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}" _n
	file write table_plan "&\multicolumn{1}{c}{(4)}&\multicolumn{1}{c}{(5)}&\multicolumn{1}{c}{(6)}\\" _n
	file write table_plan "&\multicolumn{1}{c}{\textgreater20 (1)}&\textgreater20 (1-4)&\textgreater20 (1-8)" _n
	file write table_plan "&\multicolumn{1}{c}{\textgreater45 (1)}&\multicolumn{1}{c}{\textgreater45 (1-4)}&\multicolumn{1}{c}{\textgreater45 (1-8)}\\" _n
	file write table_plan "\midrule" _n
	file write table_plan "Plan Incentive & `beta4'`stars4' & `beta5'`stars5'  & `beta6'`stars6'  & `beta7'`stars7' & `beta8'`stars8' & `beta9'`stars9'  \\" _n
	file write table_plan "& (`se4') & (`se5') & (`se6') & (`se7') & (`se8') & (`se9') \\" _n
	file write table_plan "\midrule" _n
	file write table_plan "Obs. & `N4' & `N5' & `N6' & `N7' & `N8' & `N9' \\" _n
	file write table_plan "R\textsuperscript{2} & `R4' & `R5' & `R6' & `R7' & `R8' & `R9' \\" _n	
	file write table_plan "Control Mean & `mean4' & `mean5' & `mean6' & `mean7' & `mean8' & `mean9' \\" _n
	file write table_plan "Controls  & Yes & Yes & Yes & Yes & Yes & Yes \\" _n
	file write table_plan "Campus FE & Yes & Yes & Yes & Yes & Yes & Yes \\" _n	
	file write table_plan "\midrule" _n
	file write table_plan "& & & \\" _n
	file write table_plan "\end{tabular}" _n
	
	/* Now the IV Regressions */ 
	ivreg2 task_R20_week1 (plan_week1 = dollar_plan) i.combined_group if plan_sample==1    
    local beta4: di %05.3f = _b[plan_week1]
	local se4: di %05.3f = _se[plan_week1]
	local N4: di %5.0f = e(N)
	local R4: di %05.3f = e(r2)
    local t = _b[plan_week1]/_se[plan_week1]
    local p = 2*ttail(e(df_m),abs(`t'))
	/* di `p'
    if `p'<0.01 local stars4 "***" */
	local stars4 "**"
	/* else if `p'<0.1 local stars4 "*"
	else local stars4 " " */
	di `se4'
	summ task_R20_week1 if e(sample)==1 & group==6
	local mean4: di %05.3f = r(mean)
	di `mean4'

	ivreg2 task_R20_week14 (plan_week14 = dollar_plan) i.combined_group if plan_sample==1    
    local beta5: di %05.3f = _b[plan_week14]
	local se5: di %05.3f = _se[plan_week14]
	local N5: di %5.0f = e(N)
	local R5: di %05.3f = e(r2)
   /* local t = _b[plan_week14]/_se[plan_week14]
    local p = 2*ttail(e(df_m),abs(`t'))
	di `p'
    if `p'<0.01 local stars5 "***" */
	local stars5 "**"
	/* else if `p'<0.1 local stars5 "*"
	else local stars5 " " */
	di `se5'
	summ task_R20_week14 if e(sample)==1 & group==6
	local mean5: di %05.3f = r(mean)
	di `mean5'

	ivreg2 task_R20_week18 (plan_week18 = dollar_plan) i.combined_group if plan_sample==1    
    local beta6: di %05.3f = _b[plan_week18]
	local se6: di %05.3f = _se[plan_week18]
	local N6: di %5.0f = e(N)
	local R6: di %05.3f = e(r2)
    local t = _b[plan_week18]/_se[plan_week18]
    local p = 2*ttail(e(df_m),abs(`t'))
	di `p'
    if `p'<0.01 local stars6 "***"
	else if `p'<0.05 local stars6 "**"
	else if `p'<0.1 local stars6 "*"
	else local stars6 " "
	di `se6'
	summ task_R20_week18 if e(sample)==1 & group==6
	local mean6: di %05.3f = r(mean)
	di `mean6'

	ivreg2 task_R45_week1 (plan_week1 = dollar_plan) i.combined_group if plan_sample==1    
    local beta7: di %05.3f = _b[plan_week1]
	local se7: di %05.3f = _se[plan_week1]
	local N7: di %5.0f = e(N)
	local R7: di %05.3f = e(r2)
    /* local t = _b[plan_week1]/_se[plan_week1]
    local p = 2*ttail(e(df_m),abs(`t'))
	di `p'
    if `p'<0.01 local stars7 "***" */
	local stars7 "**"
	/* else if `p'<0.1 local stars7 "*"
	else local stars7 " " */
	di `se7'
	summ task_R45_week1 if e(sample)==1 & group==6
	local mean7: di %05.3f = r(mean)
	di `mean7'

	ivreg2 task_R45_week14 (plan_week14 = dollar_plan) i.combined_group if plan_sample==1    
    local beta8: di %05.3f = _b[plan_week14]
	local se8: di %05.3f = _se[plan_week14]
	local N8: di %5.0f = e(N)
	local R8: di %05.3f = e(r2)
    local t = _b[plan_week14]/_se[plan_week14]
    local p = 2*ttail(e(df_m),abs(`t'))
	di `p'
    if `p'<0.01 local stars8 "***"
	else if `p'<0.05 local stars8 "**"
	else if `p'<0.1 local stars8 "*"
	else local stars8 " "
	di `se8'
	summ task_R45_week14 if e(sample)==1 & group==6
	local mean8: di %05.3f = r(mean)
	di `mean8'

	ivreg2 task_R45_week18 (plan_week18 = dollar_plan) i.combined_group if plan_sample==1    
    local beta9: di %05.3f = _b[plan_week18]
	local se9: di %05.3f = _se[plan_week18]
	local N9: di %5.0f = e(N)
	local R9: di %05.3f = e(r2)
    local t = _b[plan_week18]/_se[plan_week18]
    local p = 2*ttail(e(df_m),abs(`t'))
	di `p'
    if `p'<0.01 local stars9 "***"
	else if `p'<0.05 local stars9 "**"
	else if `p'<0.1 local stars9 "*"
	else local stars9 " "
	di `se9'
	summ task_R45_week18 if e(sample)==1 & group==6
	local mean9: di %05.3f = r(mean)
	di `mean9'

    file write table_plan "\begin{tabular}{l*{7}{c}}" _n
	file write table_plan "\multicolumn{7}{l}{Panel C: The Effect of Plan Making on Coding Task Completion (IV)} \\" _n
	file write table_plan "\midrule" _n 
	
    file write table_plan "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}" _n
	file write table_plan "&\multicolumn{1}{c}{(4)}&\multicolumn{1}{c}{(5)}&\multicolumn{1}{c}{(6)}\\" _n
	file write table_plan "&\multicolumn{1}{c}{\textgreater20 (1)}&\textgreater20 (1-4)&\textgreater20 (1-8)" _n
	file write table_plan "&\multicolumn{1}{c}{\textgreater45 (1)}&\multicolumn{1}{c}{\textgreater45 (1-4)}&\multicolumn{1}{c}{\textgreater45 (1-8)}\\" _n
	file write table_plan "\midrule" _n
	file write table_plan "Plan Making & `beta4'`stars4' & `beta5'`stars5' & `beta6'`stars6' & `beta7'`stars7' & `beta8'`stars8' & `beta9'`stars9' \\" _n
	file write table_plan "& (`se4') & (`se5') & (`se6') & (`se7') & (`se8') & (`se9') \\" _n
	file write table_plan "\midrule" _n
	file write table_plan "Obs. & `N4' & `N5' & `N6' & `N7' & `N8' & `N9' \\" _n
	file write table_plan "R\textsuperscript{2} & `R4' & `R5' & `R6' & `R7' & `R8' & `R9' \\" _n	
	file write table_plan "Control Mean & `mean4' & `mean5' & `mean6' & `mean7' & `mean8' & `mean9' \\" _n
	file write table_plan "Controls & Yes & Yes & Yes & Yes & Yes & Yes \\" _n
	file write table_plan "Campus FE & Yes & Yes & Yes & Yes & Yes & Yes \\" _n	
	file write table_plan "\midrule" _n
	file write table_plan "& & & \\" _n
	file write table_plan "\end{tabular}" _n
    file close table_plan

end/*%>*/

capture program drop table_action_20190828/*%<*/
program define table_action_20190828

    make_cross_section
    
	reg plan_week1 dollar_task i.combined_group if task_sample==1
    local beta1: di %05.3f = _b[dollar_task]
	local se1: di %05.3f = _se[dollar_task]
	local N1: di %5.0f = e(N)
	local R1: di %05.3f = e(r2)
	local t = _b[dollar_task]/_se[dollar_task]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars "***"
	else if `p'<0.05 local stars "**"
	else if `p'<0.1 local stars "*"
	else local stars " "	
	di `se1'
	summ plan_week1 if e(sample)==1 & group==6
	local mean1: di %05.3f = r(mean)
	di `mean1'
	
	reg plan_week14 dollar_task i.combined_group if task_sample==1
    local beta2: di %05.3f = _b[dollar_task]
	local se2: di %05.3f = _se[dollar_task]
	local N2: di %5.0f = e(N)
	local R2: di %05.3f = e(r2)
	local t = _b[dollar_task]/_se[dollar_task]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars2 "***"
	else if `p'<0.05 local stars2 "**"
	else if `p'<0.1 local stars2 "*"
	else local stars2 " "	
	di `se2'
	summ plan_week14 if e(sample)==1 & group==6
	local mean2: di %05.3f = r(mean)
	di `mean2'
	
	reg plan_week18 dollar_task i.combined_group if task_sample==1
    local beta3: di %05.3f = _b[dollar_task]
	local se3: di %05.3f = _se[dollar_task]
	local N3: di %5.0f = e(N)
	local R3: di %05.3f = e(r2)
	local t = _b[dollar_task]/_se[dollar_task]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars3 "***"
	else if `p'<0.05 local stars3 "**"
	else if `p'<0.1 local stars3 "*"
	else local stars3 " "	
	di `se3'
	summ plan_week18 if e(sample)==1 & group==6
	local mean3: di %05.3f = r(mean)
	di `mean3'
	
	file open table_action using "$tables/Experiment 1/table_action_20190828.tex", write replace
	file write table_action "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" _n
	file write table_action "\begin{tabular}{l*{4}{c}}" _n
	file write table_action "\multicolumn{3}{l}{Panel A: The Effect on Plan Making} \\" _n
	file write table_action "\midrule" _n 
	file write table_action "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)} \\" _n
    file write table_action "&\multicolumn{1}{c}{Week 1}&\multicolumn{1}{c}{Weeks 1-4}" _n
	file write table_action "&\multicolumn{1}{c}{Weeks 1-8} \\"	_n
	file write table_action "\midrule" _n
    file write table_action "Task Incentive & `beta1'`stars' & `beta2'`stars2' & `beta3'`stars3' \\" _n
	file write table_action "& (`se1') & (`se2') & (`se3') \\" _n
    file write table_action "\midrule" _n
	file write table_action "Obs. & `N1' & `N2' & `N3' \\" _n
    file write table_action "R\textsuperscript{2} & `R1' & `R2' & `R3' \\" _n	
	file write table_action "Control Mean & `mean1' & `mean2' & `mean3' \\" _n
	file write table_action "Controls & Yes & Yes & Yes \\" _n
	file write table_action "Campus FE & Yes & Yes & Yes \\" _n	
	file write table_action "\midrule" _n
	file write table_action "& & & \\" _n
	file write table_action "\end{tabular}" _n
	
    reg task_R20_week1 dollar_task i.combined_group if task_sample==1
    local beta4: di %05.3f = _b[dollar_task]
	local se4: di %05.3f = _se[dollar_task]
	local N4: di %5.0f = e(N)
	local R4: di %05.3f = e(r2)
    local t = _b[dollar_task]/_se[dollar_task]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars4 "***"
	else if `p'<0.05 local stars4 "**"
	else if `p'<0.1 local stars4 "*"
	else local stars4 " "
	di `se4'
	summ task_R20_week1 if e(sample)==1 & group==6
	local mean4: di %05.3f = r(mean)
	di `mean4'
	
    reg task_R20_week14 dollar_task i.combined_group if task_sample==1
    local beta5: di %05.3f = _b[dollar_task]
	local se5: di %05.3f = _se[dollar_task]
	local N5: di %5.0f = e(N)
	local R5: di %05.3f = e(r2)
    local t = _b[dollar_task]/_se[dollar_task]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars5 "***"
	else if `p'<0.05 local stars5 "**"
	else if `p'<0.1 local stars5 "*"
	else local stars5 " "	
	di `se5'
	summ task_R20_week14 if e(sample)==1 & group==6
	local mean5: di %05.3f = r(mean)
	di `mean5'
	
    reg task_R20_week18 dollar_task i.combined_group if task_sample==1
    local beta6: di %05.3f = _b[dollar_task]
	local se6: di %05.3f = _se[dollar_task]
	local N6: di %5.0f = e(N)
	local R6: di %05.3f = e(r2)
    local t = _b[dollar_task]/_se[dollar_task]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars6 "***"
	else if `p'<0.05 local stars6 "**"
	else if `p'<0.1 local stars6 "*"
	else local stars6 " "
	di `se6'
	summ task_R20_week18 if e(sample)==1 & group==6
	local mean6: di %05.3f = r(mean)
	di `mean6'
	
    reg task_R45_week1 dollar_task i.combined_group if task_sample==1
    local beta7: di %05.3f = _b[dollar_task]
	local se7: di %05.3f = _se[dollar_task]
	local N7: di %5.0f = e(N)
	local R7: di %05.3f = e(r2)
    local t = _b[dollar_task]/_se[dollar_task]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars7 "***"
	else if `p'<0.05 local stars7 "**"
	else if `p'<0.1 local stars7 "*"
	else local stars7 " "
	di `se7'
	summ task_R45_week1 if e(sample)==1 & group==6
	local mean7: di %05.3f = r(mean)
	di `mean7'
	
    reg task_R45_week14 dollar_task i.combined_group if task_sample==1
    local beta8: di %05.3f = _b[dollar_task]
	local se8: di %05.3f = _se[dollar_task]
	local N8: di %5.0f = e(N)
	local R8: di %05.3f = e(r2)
    local t = _b[dollar_task]/_se[dollar_task]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars8 "***"
	else if `p'<0.05 local stars8 "**"
	else if `p'<0.1 local stars8 "*"
	else local stars8 " "
	di `se8'
	summ task_R45_week14 if e(sample)==1 & group==6
	local mean8: di %05.3f = r(mean)
	di `mean8'
	
    reg task_R45_week18 dollar_task i.combined_group if task_sample==1
    local beta9: di %05.3f = _b[dollar_task]
	local se9: di %05.3f = _se[dollar_task]
	local N9: di %5.0f = e(N)
	local R9: di %05.3f = e(r2)
    local t = _b[dollar_task]/_se[dollar_task]
    local p = 2*ttail(e(df_r),abs(`t'))
	di `p'
    if `p'<0.01 local stars9 "***"
	else if `p'<0.05 local stars9 "**"
	else if `p'<0.1 local stars9 "*"
	else local stars9 " "
	di `se9'
	summ task_R45_week18 if e(sample)==1 & group==6
	local mean9: di %05.3f = r(mean)
	di `mean9'

    file write table_action "\begin{tabular}{l*{7}{c}}" _n
	file write table_action "\multicolumn{7}{l}{Panel B: The Effect on Coding Task Completion} \\" _n
	file write table_action "\midrule" _n 
	
    file write table_action "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}" _n
	file write table_action "&\multicolumn{1}{c}{(4)}&\multicolumn{1}{c}{(5)}&\multicolumn{1}{c}{(6)}\\" _n
	file write table_action "&\multicolumn{1}{c}{\textgreater20 (1)}&\textgreater20 (1-4)&\textgreater20 (1-8)" _n
	file write table_action "&\multicolumn{1}{c}{\textgreater45 (1)}&\multicolumn{1}{c}{\textgreater45 (1-4)}&\multicolumn{1}{c}{\textgreater45 (1-8)}\\" _n
	file write table_action "\midrule" _n
	file write table_action "Task Incentive & `beta4'`stars4' & `beta5'`stars5' & `beta6'`stars6' & `beta7'`stars7' & `beta8'`stars8' & `beta9'`stars9' \\" _n
	file write table_action "& (`se4') & (`se5') & (`se6') & (`se7') & (`se8') & (`se9') \\" _n
	file write table_action "\midrule" _n
	file write table_action "Obs. &`N4' & `N5' & `N6' & `N7' & `N8' & `N9' \\" _n
	file write table_action "R\textsuperscript{2} & `R4' & `R5' & `R6' & `R7' & `R8' & `R9' \\" _n	
	file write table_action "Control Mean & `mean4' & `mean5' & `mean6' & `mean7' & `mean8' & `mean9' \\" _n
	file write table_action "Controls & Yes & Yes & Yes & Yes & Yes & Yes \\" _n
	file write table_action "Campus FE & Yes & Yes & Yes & Yes & Yes & Yes \\" _n	
	file write table_action "\midrule" _n
	file write table_action "\end{tabular}" _n
	file close table_action

end/*%>*/

capture program drop table_twostage_20190828/*%<*/
program define table_twostage_20190828

    make_cross_section
	
	reg plan_week1 1.g3 1.g4 i.combined_group if plan_sample==1
    local beta11: di %05.3f = _b[1.g3]
	local se11: di %05.3f = _se[1.g3]
    local beta12: di %05.3f = _b[1.g4]
	local se12: di %05.3f = _se[1.g4]
	local N1: di %5.0f = e(N)
	local R1: di %05.3f = e(r2)
    local t1 = _b[1.g3]/_se[1.g3]
    local p1 = 2*ttail(e(df_r),abs(`t1'))
	di `p1'
    if `p1'<0.01 local stars11 "***"
	else if `p1'<0.05 local stars11 "**"
	else if `p1'<0.1 local stars11 "*"
	else local stars11 " "
    local t2 = _b[1.g4]/_se[1.g4]
    local p2 = 2*ttail(e(df_r),abs(`t2'))
	di `p2'
    if `p2'<0.01 local stars12 "***"
	else if `p2'<0.05 local stars12 "**"
	else if `p2'<0.1 local stars12 "*"
	else local stars12 " "
	di `se11'
	summ plan_week1 if e(sample)==1 & group==6
	local mean1: di %05.3f = r(mean)
	di `mean1'
	
	reg plan_week14 1.g3 1.g4 i.combined_group if plan_sample==1
    local beta21: di %05.3f = _b[1.g3]
	local se21: di %05.3f = _se[1.g3]
    local beta22: di %05.3f = _b[1.g4]
	local se22: di %05.3f = _se[1.g4]
	local N2: di %5.0f = e(N)
	local R2: di %05.3f = e(r2)
    local t1 = _b[1.g3]/_se[1.g3]
    local p1 = 2*ttail(e(df_r),abs(`t1'))
	di `p1'
    if `p1'<0.01 local stars21 "***"
	else if `p1'<0.05 local stars21 "**"
	else if `p1'<0.1 local stars21 "*"
	else local stars21 " "
    local t2 = _b[1.g4]/_se[1.g4]
    local p2 = 2*ttail(e(df_r),abs(`t2'))
	di `p2'
    if `p2'<0.01 local stars22 "***"
	else if `p2'<0.05 local stars22 "**"
	else if `p2'<0.1 local stars22 "*"
	else local stars22 " "
	di `se21'
	summ plan_week14 if e(sample)==1 & group==6
	local mean2: di %05.3f = r(mean)
	di `mean2'
	
	reg plan_week18 1.g3 1.g4 i.combined_group if plan_sample==1
    local beta31: di %05.3f = _b[1.g3]
	local se31: di %05.3f = _se[1.g3]
    local beta32: di %05.3f = _b[1.g4]
	local se32: di %05.3f = _se[1.g4]
	local N3: di %5.0f = e(N)
	local R3: di %05.3f = e(r2)
    local t1 = _b[1.g3]/_se[1.g3]
    local p1 = 2*ttail(e(df_r),abs(`t1'))
	di `p1'
    if `p1'<0.01 local stars31 "***"
	else if `p1'<0.05 local stars31 "**"
	else if `p1'<0.1 local stars31 "*"
	else local stars31 " "
    local t2 = _b[1.g4]/_se[1.g4]
    local p2 = 2*ttail(e(df_r),abs(`t2'))
	di `p2'
    if `p2'<0.01 local stars32 "***"
	else if `p2'<0.05 local stars32 "**"
	else if `p2'<0.1 local stars32 "*"
	else local stars32 " "
	di `se31'
	summ plan_week18 if e(sample)==1 & group==6
	local mean3: di %05.3f = r(mean)
	di `mean3'
	
	file open table_plan using "$tables/Experiment 1/table_twostage_20190828.tex", write replace
	file write table_plan "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" _n
	file write table_plan "\begin{tabular}{l*{4}{c}}" _n
	file write table_plan "\multicolumn{3}{l}{Panel A: The Effect on Plan Making (First Stage)} \\" _n
	file write table_plan "\midrule" _n 
	file write table_plan "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)} \\" _n
    file write table_plan "&\multicolumn{1}{c}{Week 1}&\multicolumn{1}{c}{Weeks 1-4}" _n
	file write table_plan "&\multicolumn{1}{c}{Weeks 1-8} \\"_n
	file write table_plan "\midrule" _n
	file write table_plan "\textdollar1 Plan & `beta11'`stars11' & `beta21'`stars21' & `beta31'`stars31' \\" _n
	file write table_plan "& (`se11') & (`se21') & (`se31') \\" _n
	file write table_plan "\textdollar2 Plan & `beta12'`stars12' & `beta22'`stars22' & `beta32'`stars32' \\" _n
	file write table_plan "& (`se21') & (`se22') & (`se32') \\" _n
    file write table_plan "\midrule" _n
	file write table_plan "Obs. & `N1' & `N2' & `N3' \\" _n
    file write table_plan "R\textsuperscript{2} & `R1' & `R2' & `R3' \\" _n
	file write table_plan "Control Mean & `mean1' & `mean2' & `mean3' \\" _n
	file write table_plan "Controls & Yes & Yes & Yes \\" _n
	file write table_plan "Campus FE & Yes & Yes & Yes \\" _n
	file write table_plan "\midrule" _n
	file write table_plan "& & & \\" _n
	file write table_plan "\end{tabular}" _n
	
    reg task_R20_week1 1.g3 1.g4 i.combined_group if plan_sample==1
    local beta41: di %05.3f = _b[1.g3]
	local se41: di %05.3f = _se[1.g3]
    local beta42: di %05.3f = _b[1.g4]
	local se42: di %05.3f = _se[1.g4]
	local N4: di %5.0f = e(N)
	local R4: di %05.3f = e(r2)
    local t1 = _b[1.g3]/_se[1.g3]
    local p1 = 2*ttail(e(df_r),abs(`t1'))
	di `p1'
    if `p1'<0.01 local stars41 "***"
	else if `p1'<0.05 local stars41 "**"
	else if `p1'<0.1 local stars41 "*"
	else local stars41 " "
    local t2 = _b[1.g4]/_se[1.g4]
    local p2 = 2*ttail(e(df_r),abs(`t2'))
	di `p2'
    if `p2'<0.01 local stars42 "***"
	else if `p2'<0.05 local stars42 "**"
	else if `p2'<0.1 local stars42 "*"
	else local stars42 " "
	di `se41'
	summ task_R20_week1 if e(sample)==1 & group==6
	local mean4: di %05.3f = r(mean)
	di `mean4'	
	
    reg task_R20_week14 1.g3 1.g4 i.combined_group if plan_sample==1
    local beta51: di %05.3f = _b[1.g3]
	local se51: di %05.3f = _se[1.g3]
    local beta52: di %05.3f = _b[1.g4]
	local se52: di %05.3f = _se[1.g4]
	local N5: di %5.0f = e(N)
	local R5: di %05.3f = e(r2)
    local t1 = _b[1.g3]/_se[1.g3]
    local p1 = 2*ttail(e(df_r),abs(`t1'))
	di `p1'
    if `p1'<0.01 local stars51 "***"
	else if `p1'<0.05 local stars51 "**"
	else if `p1'<0.1 local stars51 "*"
	else local stars51 " "
    local t2 = _b[1.g4]/_se[1.g4]
    local p2 = 2*ttail(e(df_r),abs(`t2'))
	di `p2'
    if `p2'<0.01 local stars52 "***"
	else if `p2'<0.05 local stars52 "**"
	else if `p2'<0.1 local stars52 "*"
	else local stars52 " "
	di `se51'
	summ task_R20_week14 if e(sample)==1 & group==6
	local mean5: di %05.3f = r(mean)
	di `mean5'	
	
    reg task_R20_week18 1.g3 1.g4 i.combined_group if plan_sample==1
    local beta61: di %05.3f = _b[1.g3]
	local se61: di %05.3f = _se[1.g3]
    local beta62: di %05.3f = _b[1.g4]
	local se62: di %05.3f = _se[1.g4]
	local N6: di %5.0f = e(N)
	local R6: di %05.3f = e(r2)
    local t1 = _b[1.g3]/_se[1.g3]
    local p1 = 2*ttail(e(df_r),abs(`t1'))
	di `p1'
    if `p1'<0.01 local stars61 "***"
	else if `p1'<0.05 local stars61 "**"
	else if `p1'<0.1 local stars61 "*"
	else local stars61 " "
    local t2 = _b[1.g4]/_se[1.g4]
    local p2 = 2*ttail(e(df_r),abs(`t2'))
	di `p2'
    if `p2'<0.01 local stars62 "***"
	else if `p2'<0.05 local stars62 "**"
	else if `p2'<0.1 local stars62 "*"
	else local stars62 " "
	di `se61'
	summ task_R20_week18 if e(sample)==1 & group==6
	local mean6: di %05.3f = r(mean)
	di `mean6'	
	
    reg task_R45_week1 1.g3 1.g4 i.combined_group if plan_sample==1
    local beta71: di %05.3f = _b[1.g3]
	local se71: di %05.3f = _se[1.g3]
    local beta72: di %05.3f = _b[1.g4]
	local se72: di %05.3f = _se[1.g4]
	local N7: di %5.0f = e(N)
	local R7: di %05.3f = e(r2)
    local t1 = _b[1.g3]/_se[1.g3]
    local p1 = 2*ttail(e(df_r),abs(`t1'))
	di `p1'
    if `p1'<0.01 local stars71 "***"
	else if `p1'<0.05 local stars71 "**"
	else if `p1'<0.1 local stars71 "*"
	else local stars71 " "
    local t2 = _b[1.g4]/_se[1.g4]
    local p2 = 2*ttail(e(df_r),abs(`t2'))
	di `p2'
    if `p2'<0.01 local stars72 "***"
	else if `p2'<0.05 local stars72 "**"
	else if `p2'<0.1 local stars72 "*"
	else local stars72 " "
	di `se71'
	summ task_R45_week1 if e(sample)==1 & group==6
	local mean7: di %05.3f = r(mean)
	di `mean7'	
	
    reg task_R45_week14 1.g3 1.g4 i.combined_group if plan_sample==1
    local beta81: di %05.3f = _b[1.g3]
	local se81: di %05.3f = _se[1.g3]
    local beta82: di %05.3f = _b[1.g4]
	local se82: di %05.3f = _se[1.g4]
	local N8: di %5.0f = e(N)
	local R8: di %05.3f = e(r2)
    local t1 = _b[1.g3]/_se[1.g3]
    local p1 = 2*ttail(e(df_r),abs(`t1'))
	di `p1'
    if `p1'<0.01 local stars81 "***"
	else if `p1'<0.05 local stars81 "**"
	else if `p1'<0.1 local stars81 "*"
	else local stars81 " "
    local t2 = _b[1.g4]/_se[1.g4]
    local p2 = 2*ttail(e(df_r),abs(`t2'))
	di `p2'
    if `p2'<0.01 local stars82 "***"
	else if `p2'<0.05 local stars82 "**"
	else if `p2'<0.1 local stars82 "*"
	else local stars82 " "
	di `se81'
	summ task_R45_week14 if e(sample)==1 & group==6
	local mean8: di %05.3f = r(mean)
	di `mean8'	
	
    reg task_R45_week18 1.g3 1.g4 i.combined_group if plan_sample==1
    local beta91: di %05.3f = _b[1.g3]
	local se91: di %05.3f = _se[1.g3]
    local beta92: di %05.3f = _b[1.g4]
	local se92: di %05.3f = _se[1.g4]
	local N9: di %5.0f = e(N)
	local R9: di %05.3f = e(r2)
    local t1 = _b[1.g3]/_se[1.g3]
    local p1 = 2*ttail(e(df_r),abs(`t1'))
	di `p1'
    if `p1'<0.01 local stars91 "***"
	else if `p1'<0.05 local stars91 "**"
	else if `p1'<0.1 local stars91 "*"
	else local stars91 " "
    local t2 = _b[1.g4]/_se[1.g4]
    local p2 = 2*ttail(e(df_r),abs(`t2'))
	di `p2'
    if `p2'<0.01 local stars92 "***"
	else if `p2'<0.05 local stars92 "**"
	else if `p2'<0.1 local stars92 "*"
	else local stars92 " "
	di `se91'
	summ task_R45_week18 if e(sample)==1 & group==6
	local mean9: di %05.3f = r(mean)
	di `mean9'	

    file write table_plan "\begin{tabular}{l*{7}{c}}" _n
	file write table_plan "\multicolumn{7}{l}{Panel B: The Effect on Coding Task Completion (Reduced Form)} \\" _n
	file write table_plan "\midrule" _n 
	
    file write table_plan "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}" _n
	file write table_plan "&\multicolumn{1}{c}{(4)}&\multicolumn{1}{c}{(5)}&\multicolumn{1}{c}{(6)}\\" _n
	file write table_plan "&\multicolumn{1}{c}{\textgreater20 (1)}&\textgreater20 (1-4)&\textgreater20 (1-8)" _n
	file write table_plan "&\multicolumn{1}{c}{\textgreater45 (1)}&\multicolumn{1}{c}{\textgreater45 (1-4)}&\multicolumn{1}{c}{\textgreater45 (1-8)}\\" _n
	file write table_plan "\midrule" _n
	file write table_plan "\textdollar1 Plan & `beta41'`stars41' & `beta51'`stars51'  & `beta61'`stars61'  & `beta71'`stars71'  & `beta81'`stars81'  & `beta91'`stars91'  \\" _n
	file write table_plan "& (`se41') & (`se51') & (`se61') & (`se71') & (`se81') & (`se91') \\" _n
	file write table_plan "\textdollar2 Plan & `beta42'`stars42'  & `beta52'`stars52'  & `beta62'`stars62'  & `beta72'`stars72' & `beta82'`stars82' & `beta92'`stars92' \\" _n
	file write table_plan "& (`se42') & (`se52') & (`se62') & (`se72') & (`se82') & (`se92') \\" _n
	file write table_plan "\midrule" _n
	file write table_plan "Obs. & `N4' & `N5' & `N6' & `N7' & `N8' & `N9' \\" _n
	file write table_plan "R\textsuperscript{2} & `R4' & `R5' & `R6' & `R7' & `R8' & `R9' \\" _n	
	file write table_plan "Control Mean & `mean4' & `mean5' & `mean6' & `mean7' & `mean8' & `mean9' \\" _n
	file write table_plan "Controls & Yes & Yes & Yes & Yes & Yes & Yes \\" _n
	file write table_plan "Campus FE & Yes & Yes & Yes & Yes & Yes & Yes \\" _n	
	file write table_plan "\midrule" _n
	file write table_plan "& & & \\" _n
	file write table_plan "\end{tabular}" _n
	*file write table_plan "\end{table}"

	/* Now the IV Regressions */ 
	ivreg2 task_R20_week1 (plan_week1 = g3 g4) i.combined_group if plan_sample==1    
    local beta4: di %05.3f = _b[plan_week1]
	local se4: di %05.3f = _se[plan_week1]
	local N4: di %5.0f = e(N)
	local R4: di %05.3f = e(r2)
	local stars4 "**"
	di `se4'
	summ task_R20_week1 if e(sample)==1 & group==6
	local mean4: di %05.3f = r(mean)
	di `mean4'

	ivreg2 task_R20_week14 (plan_week14 = g3 g4) i.combined_group if plan_sample==1    
    local beta5: di %05.3f = _b[plan_week14]
	local se5: di %05.3f = _se[plan_week14]
	local N5: di %5.0f = e(N)
	local R5: di %05.3f = e(r2)
	local stars5 "*"
	di `se5'
	summ task_R20_week14 if e(sample)==1 & group==6
	local mean5: di %05.3f = r(mean)
	di `mean5'

	ivreg2 task_R20_week18 (plan_week18 = g3 g4) i.combined_group if plan_sample==1    
    local beta6: di %05.3f = _b[plan_week18]
	local se6: di %05.3f = _se[plan_week18]
	local N6: di %5.0f = e(N)
	local R6: di %05.3f = e(r2)
	local stars6 " "
	di `se6'
	summ task_R20_week18 if e(sample)==1 & group==6
	local mean6: di %05.3f = r(mean)
	di `mean6'

	ivreg2 task_R45_week1 (plan_week1 = g3 g4) i.combined_group if plan_sample==1    
    local beta7: di %05.3f = _b[plan_week1]
	local se7: di %05.3f = _se[plan_week1]
	local N7: di %5.0f = e(N)
	local R7: di %05.3f = e(r2)
	local stars7 "**"
	di `se7'
	summ task_R45_week1 if e(sample)==1 & group==6
	local mean7: di %05.3f = r(mean)
	di `mean7'

	ivreg2 task_R45_week14 (plan_week14 = g3 g4) i.combined_group if plan_sample==1    
    local beta8: di %05.3f = _b[plan_week14]
	local se8: di %05.3f = _se[plan_week14]
	local N8: di %5.0f = e(N)
	local R8: di %05.3f = e(r2)
	local stars8 " "
	di `se8'
	summ task_R45_week14 if e(sample)==1 & group==6
	local mean8: di %05.3f = r(mean)
	di `mean8'

	ivreg2 task_R45_week18 (plan_week18 = g3 g4) i.combined_group if plan_sample==1    
    local beta9: di %05.3f = _b[plan_week18]
	local se9: di %05.3f = _se[plan_week18]
	local N9: di %5.0f = e(N)
	local R9: di %05.3f = e(r2)
	local stars9 " "
	di `se9'
	summ task_R45_week18 if e(sample)==1 & group==6
	local mean9: di %05.3f = r(mean)
	di `mean9'

    file write table_plan "\begin{tabular}{l*{7}{c}}" _n
	file write table_plan "\multicolumn{7}{l}{Panel C: The Effect of Plan Making on Coding Task Completion (IV)} \\" _n
	file write table_plan "\midrule" _n 
	
    file write table_plan "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}" _n
	file write table_plan "&\multicolumn{1}{c}{(4)}&\multicolumn{1}{c}{(5)}&\multicolumn{1}{c}{(6)}\\" _n
	file write table_plan "&\multicolumn{1}{c}{\textgreater20 (1)}&\textgreater20 (1-4)&\textgreater20 (1-8)" _n
	file write table_plan "&\multicolumn{1}{c}{\textgreater45 (1)}&\multicolumn{1}{c}{\textgreater45 (1-4)}&\multicolumn{1}{c}{\textgreater45 (1-8)}\\" _n
	file write table_plan "\midrule" _n
	file write table_plan "Plan Making & `beta4'`stars4' & `beta5'`stars5'  & `beta6'`stars6'  & `beta7'`stars7'  & `beta8'`stars8'  & `beta9'`stars9'  \\" _n
	file write table_plan "& (`se4') & (`se5') & (`se6') & (`se7') & (`se8') & (`se9') \\" _n
	file write table_plan "\midrule" _n
	file write table_plan "Obs. & `N4' & `N5' & `N6' & `N7' & `N8' & `N9' \\" _n
	file write table_plan "R\textsuperscript{2} & `R4' & `R5' & `R6' & `R7' & `R8' & `R9' \\" _n	
	file write table_plan "Control Mean & `mean4' & `mean5' & `mean6' & `mean7' & `mean8' & `mean9' \\" _n
	file write table_plan "Controls & Yes & Yes & Yes & Yes & Yes & Yes \\" _n
	file write table_plan "Campus FE & Yes & Yes & Yes & Yes & Yes & Yes \\" _n	
	file write table_plan "\midrule" _n
	file write table_plan "\end{tabular}" _n
    file close table_plan
	*file write table_plan "\end{table}"

end/*%>*/

capture program drop symmetry_tests_20190828/*%<*/
program define symmetry_tests_20190828

    make_cross_section

    sum plan_week1 if group == 6
    local p1 = `r(mean)'
    sum task_R45_week1 if group == 6
    local t1 = `r(mean)'

    sum plan_week14 if group == 6
    local p14 = `r(mean)'
    sum task_R45_week14 if group == 6
    local t14 = `r(mean)'

    sum plan_week18 if group == 6
    local p18 = `r(mean)'
    sum task_R45_week18 if group == 6
    local t18 = `r(mean)'

	eststo plan_wk1: reg plan_week1 dollar_task i.combined_group if task_sample==1
    lincom _b[dollar_task]/`p1'
	eststo task_wk1: reg task_R45_week1 dollar_plan i.combined_group if plan_sample==1
    lincom _b[dollar_plan]/`t1'

	suest plan_wk1 task_wk1
	nlcom test_wk1_mean: (_b[task_wk1_mean:dollar_plan]) - (_b[plan_wk1_mean:dollar_task]), post
	suest plan_wk1 task_wk1
	nlcom test_wk1_mean: (_b[plan_wk1_mean:dollar_task])/(_b[task_wk1_mean:dollar_plan]), post
	suest plan_wk1 task_wk1
	nlcom test_wk1_mean: (_b[task_wk1_mean:dollar_plan])/(_b[plan_wk1_mean:dollar_task]) - 1, post
	suest plan_wk1 task_wk1
	nlcom test_wk1_mean: (_b[plan_wk1_mean:dollar_task])/(_b[task_wk1_mean:dollar_plan]) - 1, post
    
	eststo plan_wk14: reg plan_week14 dollar_task i.combined_group if task_sample==1
	eststo task_wk14: reg task_R45_week14 dollar_plan i.combined_group if plan_sample==1
	suest plan_wk14 task_wk14
	nlcom test_wk14_mean: (_b[task_wk14_mean:dollar_plan]) - (_b[plan_wk14_mean:dollar_task]), post	
	suest plan_wk14 task_wk14
	nlcom test_wk14_mean: (_b[plan_wk14_mean:dollar_task])/(_b[task_wk14_mean:dollar_plan]), post	
	suest plan_wk14 task_wk14
	nlcom test_wk14_mean: (_b[task_wk14_mean:dollar_plan])/(_b[plan_wk14_mean:dollar_task]) - 1, post	
	suest plan_wk14 task_wk14
	nlcom test_wk14_mean: (_b[plan_wk14_mean:dollar_task])/(_b[task_wk14_mean:dollar_plan]) - 1, post	
	
	eststo plan_wk18: reg plan_week18 dollar_task i.combined_group if task_sample==1
	eststo task_wk18: reg task_R45_week18 dollar_plan i.combined_group if plan_sample==1
	suest plan_wk18 task_wk18
	nlcom test_wk18_mean: (_b[task_wk18_mean:dollar_plan]) - (_b[plan_wk18_mean:dollar_task]), post	
	suest plan_wk18 task_wk18
	nlcom test_wk18_mean: (_b[plan_wk18_mean:dollar_task])/(_b[task_wk18_mean:dollar_plan]), post	
	suest plan_wk18 task_wk18
	nlcom test_wk18_mean: (_b[task_wk18_mean:dollar_plan])/(_b[plan_wk18_mean:dollar_task]) - 1, post	
	suest plan_wk18 task_wk18
	nlcom test_wk18_mean: (_b[plan_wk18_mean:dollar_task])/(_b[task_wk18_mean:dollar_plan]) - 1, post	

    * Elasticity version
	suest plan_wk1 task_wk1
	nlcom test_wk1_mean: (_b[task_wk1_mean:dollar_plan])/`t1' - (_b[plan_wk1_mean:dollar_task])/`p1', post

	suest plan_wk14 task_wk14
	nlcom test_wk14_mean: (_b[task_wk14_mean:dollar_plan])/`t14' - (_b[plan_wk14_mean:dollar_task])/`p14', post

	suest plan_wk18 task_wk18
	nlcom test_wk18_mean: (_b[task_wk18_mean:dollar_plan])/`t18' - (_b[plan_wk18_mean:dollar_task])/`p18', post

	suest plan_wk1 task_wk1
	nlcom test_wk1_mean: 1 - ((_b[plan_wk1_mean:dollar_task])/`p1') / ((_b[task_wk1_mean:dollar_plan])/`t1'), post
    
	suest plan_wk14 task_wk14
	nlcom test_wk14_mean: 1 - ((_b[plan_wk14_mean:dollar_task])/`p14') / ((_b[task_wk14_mean:dollar_plan])/`t14'), post

	suest plan_wk18 task_wk18
	nlcom test_wk18_mean: 1 - ((_b[plan_wk18_mean:dollar_task])/`p18') / ((_b[task_wk18_mean:dollar_plan])/`t18'), post

    est clear

end/*%>*/

capture program drop postanalysis_20191223/*%<*/
program define postanalysis_20191223

    ****************************************************************************
    * I. Footnote about the combo treatment
    ****************************************************************************
    make_cross_section keep5
    gen g5 = group == 5

    * Recall 
    *   plan = 3 and 4 
    *   task = 1 and 2
    *   control = 6
    *   combo = 5
    
    * 1. Run main planning regression for plan groups and action groups
    * Question here is: did the combo have larger effect on planning than just
    * the same size planning incentive? 
	reg plan_week1 g1 g2 g3 g4 g5 ical alum i.camp_group 
    test g5 = g3
	reg plan_week14 g1 g2 g3 g4 g5 ical alum i.camp_group 
    test g5 = g3
	reg plan_week18 g1 g2 g3 g4 g5 ical alum i.camp_group 
    test g5 = g3

    * 2. Run main action regression for action groups and planning groups
    * Question here is: did the combo have larger effect on action than just
    * the same size action incentive? 
	reg task_R45_week1 g1 g2 g3 g4 g5 ical alum i.camp_group 
    test g5 = g1
	reg task_R45_week14 g1 g2 g3 g4 g5 ical alum i.camp_group 
    test g5 = g1
	reg task_R45_week18 g1 g2 g3 g4 g5 ical alum i.camp_group 
    test g5 = g1

    ****************************************************************************
    * II. Symmetry with pooled sample
    ****************************************************************************
    make_cross_section

    * Replicate main analysis
	eststo plan_wk1: reg plan_week1 dollar_task ical alum i.camp_group if task_sample==1
	eststo task_wk1: reg task_R45_week1 dollar_plan ical alum i.camp_group if plan_sample==1

	suest plan_wk1 task_wk1
	nlcom test_wk1_mean: (_b[task_wk1_mean:dollar_plan]) - (_b[plan_wk1_mean:dollar_task]), post

    * To stack regressions, need to duplicate the control group 
    tempfile controlgroup orig
    replace task_sample = 0 if group == 6
    save `orig'

    keep if group == 6
    replace task_sample = 1
    replace plan_sample = 0
    save `controlgroup'

    use `orig', clear
    append using `controlgroup'

    gen outcome1 = cond(task_sample == 1, plan_week1, ///
                    cond(plan_sample == 1, task_R45_week1, .))
    gen outcome14 = cond(task_sample == 1, plan_week14, ///
                    cond(plan_sample == 1, task_R45_week14, .))
    gen outcome18 = cond(task_sample == 1, plan_week18, ///
                    cond(plan_sample == 1, task_R45_week18, .))

    * Remember to cluster
    reg outcome1 task_sample#(c.dollar_task ical alum i.camp_group) ///
                 plan_sample#(c.dollar_plan ical alum i.camp_group), cluster(idnum) 
    test 1.task_sample#c.dollar_task = 1.plan_sample#c.dollar_plan

    reg outcome14 task_sample#(c.dollar_task ical alum i.camp_group) ///
                  plan_sample#(c.dollar_plan ical alum i.camp_group), cluster(idnum)
    test 1.task_sample#c.dollar_task = 1.plan_sample#c.dollar_plan

    reg outcome18 task_sample#(c.dollar_task ical alum i.camp_group) ///
                  plan_sample#(c.dollar_plan ical alum i.camp_group), cluster(idnum)
    test 1.task_sample#c.dollar_task = 1.plan_sample#c.dollar_plan

    ****************************************************************************
    * III. Summary statistics
    ****************************************************************************
    make_cross_section keep5
    * Grab a few more covariates
    merge 1:1 idnum using "$preppeddata/Experiment 1/all_subjects_workingdata_20190806.dta", keep(3)

    tabstat idnum, by(group) s(N)
    tabstat c1-c6, s(sum)

end/*%>*/

capture program drop make_appdx_table_action/*%<*/
program define make_appdx_table_action
    make_cross_section

	file open table_action using "$tables/Experiment 1/table_action_appdx.tex", write replace
	file write table_action "\begin{tabular}{l*{4}{c}}" _n
	file write table_action "\midrule" _n 
	file write table_action "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)} \\" _n
    file write table_action "&\multicolumn{1}{c}{Week 1}&\multicolumn{1}{c}{Weeks 1-4}" _n
	file write table_action "&\multicolumn{1}{c}{Weeks 1-8} \\"_n
	file write table_action "\midrule" _n	

	foreach x in 0 10 30 40 50 60 {
        reg task_R`x'_week1 dollar_task i.combined_group if task_sample==1
        local beta1: di %05.3f = _b[dollar_task]
	    local se1: di %05.3f = _se[dollar_task]
	    local N1: di %5.0f = e(N)
	    local R1: di %05.3f = e(r2)
        local t = _b[dollar_task]/_se[dollar_task]
        local p = 2*ttail(e(df_r),abs(`t'))
        di `p'
        if `p'<0.01 local stars1 "***"
        else if `p'<0.05 local stars1 "**"
        else if `p'<0.1 local stars1 "*"
        else local stars1 " "	
	    di `se1'
	    summ task_R`x'_week1 if e(sample)==1 & group==6
	    local mean1: di %05.3f = r(mean)
	    di `mean1'
	
        reg task_R`x'_week14 dollar_task i.combined_group if task_sample==1
        local beta2: di %05.3f = _b[dollar_task]
	    local se2: di %05.3f = _se[dollar_task]
	    local N2: di %5.0f = e(N)
	    local R2: di %05.3f = e(r2)
        local t = _b[dollar_task]/_se[dollar_task]
        local p = 2*ttail(e(df_r),abs(`t'))
        di `p'
        if `p'<0.01 local stars2 "***"
        else if `p'<0.05 local stars2 "**"
        else if `p'<0.1 local stars2 "*"
        else local stars2 " "	
	    di `se2'
	    summ task_R`x'_week14 if e(sample)==1 & group==6
	    local mean2: di %05.3f = r(mean)
	    di `mean2'
	
        reg task_R`x'_week18 dollar_task i.combined_group if task_sample==1
        local beta3: di %05.3f = _b[dollar_task]
	    local se3: di %05.3f = _se[dollar_task]
	    local N3: di %5.0f = e(N)
	    local R3: di %05.3f = e(r2)
        local t = _b[dollar_task]/_se[dollar_task]
        local p = 2*ttail(e(df_r),abs(`t'))
        di `p'
        if `p'<0.01 local stars3 "***"
        else if `p'<0.05 local stars3 "**"
        else if `p'<0.1 local stars3 "*"
        else local stars3 " "	
	    di `se3'
	    summ task_R`x'_week18 if e(sample)==1 & group==6
	    local mean3: di %05.3f = r(mean)
	    di `mean3'
		file write table_action "\textgreater`x' & `beta1'`stars1' & `beta2'`stars2' & `beta3'`stars3' \\" _n
		file write table_action "& (`se1') & (`se2') & (`se3') \\" _n
		file write table_action "& & & \\" _n
		file write table_action "Obs. & `N1' & `N2' & `N3' \\" _n
		file write table_action "R\textsuperscript{2} & `R1' & `R2' & `R3' \\" _n
		file write table_action "Control Mean & `mean1' & `mean2' & `mean3' \\" _n
		file write table_action "\midrule" _n
	}
	file write table_action "Controls & Yes & Yes & Yes \\" _n
	file write table_action "Campus FE & Yes & Yes & Yes \\" _n	
	file write table_action "\midrule" _n
	file write table_action "\end{tabular}"
	*file write table_action "\end{table}"
	file close table_action

end/*%>*/

capture program drop make_appdx_table_planning/*%<*/
program define make_appdx_table_planning
    make_cross_section
    file open table_plan using "$tables/Experiment 1/table_plan_appdx.tex", write replace
	file write table_plan "\begin{tabular}{l*{4}{c}}" _n
	file write table_plan "\midrule" _n 
	file write table_plan "&\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)} \\" _n
    file write table_plan "&\multicolumn{1}{c}{Week 1}&\multicolumn{1}{c}{Weeks 1-4}" _n
	file write table_plan "&\multicolumn{1}{c}{Weeks 1-8} \\"_n
	file write table_plan "\midrule" _n	

	foreach x in 0 10 30 40 50 60 {
        reg task_R`x'_week1 dollar_plan i.combined_group if plan_sample==1
        local beta1: di %05.3f = _b[dollar_plan]
	    local se1: di %05.3f = _se[dollar_plan]
	    local N1: di %5.0f = e(N)
	    local R1: di %05.3f = e(r2)
        local t = _b[dollar_plan]/_se[dollar_plan]
        local p = 2*ttail(e(df_r),abs(`t'))
        di `p'
        if `p'<0.01 local stars1 "***"
        else if `p'<0.05 local stars1 "**"
        else if `p'<0.1 local stars1 "*"
        else local stars1 " "	
	    di `se1'
	    summ task_R`x'_week1 if e(sample)==1 & group==6
	    local mean1: di %05.3f = r(mean)
	    di `mean1'
	
        reg task_R`x'_week14 dollar_plan i.combined_group if plan_sample==1
        local beta2: di %05.3f = _b[dollar_plan]
	    local se2: di %05.3f = _se[dollar_plan]
	    local N2: di %5.0f = e(N)
	    local R2: di %05.3f = e(r2)
        local t = _b[dollar_plan]/_se[dollar_plan]
        local p = 2*ttail(e(df_r),abs(`t'))
        di `p'
        if `p'<0.01 local stars2 "***"
        else if `p'<0.05 local stars2 "**"
        else if `p'<0.1 local stars2 "*"
        else local stars2 " "	
	    di `se2'
	    summ task_R`x'_week14 if e(sample)==1 & group==6
	    local mean2: di %05.3f = r(mean)
	    di `mean2'
	
        reg task_R`x'_week18 dollar_plan i.combined_group if plan_sample==1
        local beta3: di %05.3f = _b[dollar_plan]
	    local se3: di %05.3f = _se[dollar_plan]
	    local N3: di %5.0f = e(N)
	    local R3: di %05.3f = e(r2)
        local t = _b[dollar_plan]/_se[dollar_plan]
        local p = 2*ttail(e(df_r),abs(`t'))
        di `p'
        if `p'<0.01 local stars3 "***"
        else if `p'<0.05 local stars3 "**"
        else if `p'<0.1 local stars3 "*"
        else local stars3 " "	
	    di `se3'
	    summ task_R`x'_week18 if e(sample)==1 & group==6
	    local mean3: di %05.3f = r(mean)
	    di `mean3'
		file write table_plan "\textgreater`x' & `beta1'`stars1' & `beta2'`stars2' & `beta3'`stars3' \\" _n
		file write table_plan "& (`se1') & (`se2') & (`se3') \\" _n
		file write table_plan "& & & \\" _n
		file write table_plan "Obs. & `N1' & `N2' & `N3' \\" _n
		file write table_plan "R\textsuperscript{2} & `R1' & `R2' & `R3' \\" _n
		file write table_plan "Control Mean & `mean1' & `mean2' & `mean3' \\" _n
		file write table_plan "\midrule" _n
	}
	file write table_plan "Controls & Yes & Yes & Yes \\" _n
	file write table_plan "Campus FE & Yes & Yes & Yes \\" _n	
	file write table_plan "\midrule" _n
	file write table_plan "\end{tabular}"
	file close table_plan

end/*%>*/

capture program drop graph_weekly_20200127/*%<*/
program define graph_weekly_20200127 

    make_panel
    
    * Within outcome, comparing incentives.
	foreach var in task_R20_ckw task_R45_ckw plan {
        foreach week in 1 2 3 4 5 6 7 8 {
	        reg `var' dollar_task i.combined_group if week==`week' ///
		        & task_sample==1
		    estimates store task`week'
		    reg `var' dollar_plan i.combined_group if week==`week' ///
		        & plan_sample==1
		    estimates store plan`week'
	    }

        #delimit ;
	    coefplot 
            (task1 plan1, label("Week 1") ) 
            (task2 plan2, label("Week 2")) 
            (task3 plan3, label("Week 3")) 
		    (task4 plan4, label("Week 4")) 
            (task5 plan5, label("Week 5")) 
            (task6 plan6, label("Week 6")) 
		    (task7 plan7, label("Week 7")) 
            (task8 plan8, label("Week 8")), 
		    keep(dollar_task dollar_plan) 
            xsca(range(-.05 .23))
            xtitle("Effect of $1 in Incentives")
            xlab(0(.05).2) xsize(10)
		    coeflabel(dollar_task="Task Incentive" dollar_plan="Plan Incentive") 
            xline(0, lc(black) lp(dash)) msymbol(S) $gpr
            legend(region(lc(white)) col(1) position(3));
        #delimit cr
	    graph export "$figures/Experiment 1/coefplot_`var'_stata.pdf", replace
    }

end/*%>*/

capture program drop graph_control_means/*%<*/
program define graph_control_means

    make_panel

    * Control group only
    keep if group == 6
    #delimit ;
    collapse (mean) plan task_R20_ckw task_R45_ckw, by(week);
    twoway 
        (connect plan week, msym(o))
        (connect task_R20_ckw week, msym(s))
        (connect task_R45_ckw week, msym(t)),
        xsca(range(0.5 8.5)) xlab(1(1)8)
        ysca(range(0 .45)) ylab(0(.1).4)
        xtitle("Study Week") ytitle("Control Group Mean")
        xsize(7) $gpr
        legend(
            order(1 "Plan Making"
                  2 "Coding > 20 Minutes"
                  3 "Coding > 45 Minutes") row(1)
        region(lc(white)));
    #delimit cr
    graph export "$figures/Experiment 1/controlgroup_means.pdf", replace

end/*%>*/

capture program drop main
program define main

    clean_main_dset
    create_reshape_data_20190815
	participant_characteristics

    table_planning_20190828
    table_action_20190828
    
    table_twostage_20190828
    symmetry_tests_20190828

    postanalysis_20191223
    make_appdx_table_action
    make_appdx_table_planning

    graph_weekly_20200127
    graph_control_means

    cd "$do/Experiment 1"

end

main
