/******************************************************************************

DropTopandBottomCoded.do

This file creates indicators to drop subjects who were top-coded in any of their
 $3 or $11 MPL decisions or were bottom-coded in any of their $4 or $12 MPL 
 decisions. We merge this in with the main data in our analysis files.

*******************************************************************************/


** Load data
local filename_wtp "wtp_pooled_exp2.dta"

use "$preppeddata/Experiment 2/`filename_wtp'", clear

** Gen top and bottom-coded variables
gen top_coded = (payment == 3 | payment == 11) & choice == "0left"
gen bottom_coded = (payment == 4 | payment == 12) & choice == "33left"

** Collapse by mturkid to sum
collapse (sum) top_coded bottom_coded, by(mturkid)

** Create indicator for top and bottom coding
gen no_top_bottom_coding = (top_coded == 0 & bottom_coded == 0)

** Count top or bottom censored people
count if no_top_bottom_coding == 0
local topbottomcensored `r(N)'
latex_write \censoreddrop "`topbottomcensored'"

** Count people who are not top or bottom censored (i.e., final sample)
count if no_top_bottom_coding == 1
local finalsample `r(N)'
latex_write \finalsample "`finalsample'"

** Keep mturkid and main variables
keep mturkid no_top_bottom_coding

** Save to use for merging
save "$preppeddata/Experiment 2/topbottomcoded.dta", replace
