/******************************************************************************

Exp2Build.do

This file prepares data from Experiment 2.

*******************************************************************************/

** Define local to mark tex files for different versions of the data
local marker "pooled"
local text_only_marker "pooled"

use "$rawdata/Experiment 2/Part 1 Data", clear

** Filter out participants who failed the attention checks across each pilot
** Save # dropped in local to keep track of how many are dropped for each attention check

** Remove if ineligible
drop if ineligible == "true"
local ineligible_drop `r(N_drop)'

** Only keep first attempt from each participant
bysort mturkid (startdate): keep if _n == 1
local duplicate_drop `r(N_drop)'

count
local eligible_participants `r(N)'

** Drop if failed captcha
gen failed_captcha = !(q42 == "T2YKA" | q52 == "T2YKA") 
drop if failed_captcha
local captcha_drop `r(N_drop)'
drop failed_captcha

drop if (strpos(q63, "I will not have the opportunity to earn any bonus payments.") ///
	| strpos(q63, "I will also earn $2 for sure in part 2.")) 
local study_comprehension1 `r(N_drop)'

drop if !strpos(q64, `"I will answer 40 hypothetical questions about gambles, and what I choose will not affect my payment (except that I must answer all 40 questions to earn a "part 2 bonus" payment)."')
local study_comprehension2 `r(N_drop)'

** These questions are on the same screen so we'll keep track of "at least one wrong"
local study_comphrehension_drop = `study_comprehension1' + `study_comprehension2'

drop if q536 != "True"
local reminders_comprehension_drop `r(N_drop)'

drop if !strpos(q109, "You will NOT get three reminder emails. You will get the amount of money listed in the option on the left.")
local mpl_comphrehension1 `r(N_drop)'

drop if !strpos(q110, "You will get three reminder emails. You will get the amount of money listed in the option on the right.")
local mpl_comphrehension2 `r(N_drop)'

** These questions are on the same screen so we'll keep track of "at least one wrong"
local mpl_comphrehension_drop = `mpl_comphrehension1' + `mpl_comphrehension2'

** Drop people who failed the MPL attention checks
drop if xnorm_0choicefinal != ""
local mplattentiondrop `r(N_drop)'

count
local afterattentioncheck `r(N)'
local droppedattncheck = `eligible_participants' - `afterattentioncheck'

** Drop if any payment or delay data & demographics are missing — left survey early
foreach i of numlist 1/16 {
	drop if (missing(xnorm_`i'payment) | missing(xnorm_`i'payment)) ///
	& missing(age)
	local leftsurveyearly = `leftsurveyearly' + `r(N_drop)'
}

** Drop if any payment or delay data & demographics are missing — left survey early
foreach i of numlist 1/16 {
	drop if (missing(xnorm_`i'payment) | missing(xnorm_`i'payment)) ///
	& missing(age)
	local leftsurveyearly = `leftsurveyearly' + `r(N_drop)'
}

** Get count of all participants who successfully completed the survey
count
local fullcount `r(N)'

** Write all of the attention check locals to Latex
latex_write dropcaptcha`text_only_marker' "`captcha_drop'"
latex_write duplicatedrop`text_only_marker' "`duplicate_drop'"
latex_write dropreminderscomprehension`text_only_marker' "`reminders_comprehension_drop'"
latex_write studycomphrehensiondrop`text_only_marker' "`study_comphrehension_drop'"
latex_write mplcomphrehensiondrop`text_only_marker' "`mpl_comphrehension_drop'"
latex_write ineligibledrop`text_only_marker' "`ineligible_drop'"
latex_write mplattentiondrop`text_only_marker' "`mplattentiondrop'"
latex_write leftsurveyearly`text_only_marker' "`leftsurveyearly'"
latex_write \fullcount "`fullcount'"
latex_write \eligibleparticipants "`eligible_participants'"
latex_write \droppedattncheck "`droppedattncheck'"

** Save our intermediate stage
save `"$preppeddata/Experiment 2/wtp_intermediate_`marker'_exp2.dta"', replace

** Keep relevant variables — xnorm variables are about choices 
keep mturkid xnorm_?delay xnorm_?idfinal xnorm_?payment xnorm_?choicefinal xnorm_?time ///
	xnorm_??delay xnorm_??idfinal xnorm_??payment xnorm_??choicefinal xnorm_??time ///
	source paymentcode link

** Add whether low or high MPL was seen first
gen low_MPL_first = (xnorm_1payment == "$3" | xnorm_1payment == "$4")
 
 
** Reshape from wide to long
reshape long xnorm_@delay xnorm_@payment xnorm_@choicefinal xnorm_@idfinal xnorm_@time, ///
 i(mturkid) j(counter)

** Convert to numeric
replace xnorm_payment = substr(xnorm_payment, 2, .)
destring xnorm_payment, replace
destring xnorm_idfinal, replace
destring xnorm_time, replace

** Convert delay to days
gen delay = 2 if xnorm_delay == "2 days"
gen weeks = substr(xnorm_delay, 1, 1) if strpos(xnorm_delay, "week")
destring weeks, replace
replace delay = 7 * weeks if strpos(xnorm_delay, "week")
drop xnorm_delay

** Rename for clarity
rename xnorm_choicefinal choice
rename xnorm_payment payment
rename xnorm_idfinal choicenum
rename xnorm_time time

** Drop the choices from the attention check MPL
drop if counter == 0

** Drop people who saw the same screen more than once or saw a wrong
** combination of screens

egen payment_sum = total(payment), by(mturkid)
egen delay_sum = total(delay), by(mturkid)

drop if payment_sum != 120 | delay_sum != 288
local technicalproblemdrop1 `r(N_drop)' / 16

drop payment_sum delay_sum

drop if link == ""
local technicalproblemdrop2 = `r(N_drop)' / 16

local technicalproblemdrop = `technicalproblemdrop1' + `technicalproblemdrop2'

** Write all of the attention check locals to Latex
latex_write droptechnical`text_only_marker' "`technicalproblemdrop'"

** Only keep participants who can be matched to CloudResearch data
merge m:1 mturkid using `"$rawdata/Experiment 2/FinalMTurkIDs"'
drop if _merge == 1
local nocloudresearchmatch = `r(N_drop)' / 16
latex_write matchproblem`text_only_marker' "`nocloudresearchmatch'"
keep if _merge == 3

local excluded = `nocloudresearchmatch' + `technicalproblemdrop'
latex_write \excludednumber "`excluded'"

local fullcountminusexcluded = 	`fullcount' - `excluded'
latex_write \fullcountminusexcluded "`fullcountminusexcluded'"

replace mturkid = amazonidentifier
drop amazonidentifier
drop _merge

*******************************************************************************

** Convert choices to terms of left
replace choicenum = choicenum - 1 if strpos(choice, "right")

** Convert string choice
replace choice = string(choicenum) + "left" if strpos(choice, "right")

** Add number of times 1 left was chosen
gen strategy_1left = (choice == "1left")
egen times_1left = total(strategy_1left), by(mturkid)
drop strategy_1left

** Add increments & max bonus of MPL by incentive
gen increment = 0.75 if inlist(payment, 11, 12)
replace increment = 0.25 if inlist(payment, 3, 4)

gen max_bonus = 12 if inlist(payment, 11, 12)
replace max_bonus = 4 if inlist(payment, 3, 4)

** Calculate WTP (WTP is equated with the midpoint of the crossover interval.) 
gen WTP = ((max_bonus - (choicenum -1) * increment) + ///
(max_bonus - (choicenum *increment))) / 2 if choicenum >= 17

replace WTP = -((max_bonus - (32 - choicenum) * increment) ///
+ (max_bonus - (33 - choicenum) * increment)) / 2 if choicenum < 17

*******************************************************************************
** Keep only relevant variables
keep mturkid delay payment time WTP max_bonus times_1left choice ///
source counter low_MPL_first

** Save prepped data
save `"$preppeddata/Experiment 2/wtp_`marker'_exp2.dta"', replace

*******************************************************************************
** Create demographic and time set

** Load intermediate data set from above 
local marker "pooled"
use `"$preppeddata/Experiment 2/wtp_intermediate_`marker'_exp2.dta"', clear

** Keep relevant variables
keep mturkid durationinseconds age gender education income source

** Change 91+ to 91 so we can destring
replace age = "91" if age == "91+"

** Order, destring
order mturkid 
destring durationinseconds age, replace

** Create labels for education so the encoded order is logical
label define education_lbl 1 "High School or equivalent" ///
2 "Some college" 3 "College Graduate with Associate's Degree (2 year)" ///
4 "College Graduate with Bachelor's Degree (4 year)" ///
5 "Master's Degree (MS)" 6 "Professional Degree (MD, JD, etc.)" /// 
7 "Doctoral Degree (PhD)"

** For income, add / so it'll format correctly in Latex
replace income = subinstr(income, "$", "", .) 

** Create labels for income so the encoded order is logical
label define income_lbl 1 "Less than 10,000" ///
2 "10,000 to 14,999" 3 "15,000 to 24,999" ///
4 "25,000 to 34,999" 5 "35,000 to 49,999" ///
6 "50,000 to 74,999" 7 "75,000 to 99,999" ///
8 "100,000 to 149,999" 9 "150,000 to 199,999" ///
10 "200,000 or more"

** Encode variables
encode education, gen(encode_education) label(education_lbl)
drop education
rename encode_education education

encode income, gen(encode_income) label(income_lbl)
drop income
rename encode_income income

encode gender, gen(encode_gender)
drop gender
rename encode_gender gender

** Save prepped data
save `"$preppeddata/Experiment 2/`marker'_exp2_demographic.dta"', replace
*****************

** For intermediate data, only keep participants who can be matched to CloudResearch data
use `"$preppeddata/Experiment 2/wtp_intermediate_`marker'_exp2.dta"', clear

merge m:1 mturkid using `"$rawdata/Experiment 2/FinalMTurkIDs"'
keep if _merge == 3
replace mturkid = amazonidentifier
drop amazonidentifier
drop _merge

save `"$preppeddata/Experiment 2/wtp_intermediate_`marker'_exp2.dta"', replace


****** Run other secondary build files
run "$do/Experiment 2/Build/DropTopandBottomCoded.do"
run "$do/Experiment 2/Build/Exp2CompRateBuild.do"
