/******************************************************************************

Exp2CompRateBuild.do

This file prepares completion data from Experiment 2.

*******************************************************************************/

*******************************************************************************
** Part 2 Qualtrics Responses
*******************************************************************************

use "$rawdata/Experiment 2/Part 2 Data", clear

** Keep relevant variables
keep mturkid source delay

** Change data type of mturkid
recast str20 mturkid

tempfile part2ids
save `part2ids'

*******************************************************************************
** Part 1 Qualtrics Responses
*******************************************************************************

** Load data
local marker "pooled"
use `"$preppeddata/Experiment 2/wtp_intermediate_`marker'_exp2.dta"', clear

** Add delay group & only keep delays we have data on
destring link_version, replace
gen delay = . 
replace delay = 2 if link_version == 1
replace delay = 7 if link_version == 2
replace delay = 21 if link_version == 3
replace delay = 42 if link_version == 4

** Destring reminder
destring reminder, replace

** Make reminder variable clearer: reminder = 2 means no reminder,
** so let's make remainder = 0 mean no reminder instead
** (Reminder = 3 means the 10% who had MPL row chosen)
replace reminder = 0 if reminder == 2 

** Make bonus numeric
replace bonus2 = substr(bonus2, 2, .)
destring bonus2, replace

** Keep relevant variables
keep mturkid reminder delay bonus2 source

tempfile part1ids
save `part1ids'

*******************************************************************************
** Merge Part 1 / Part 2 Qualtrics Responses
*******************************************************************************
merge 1:1 mturkid  using `part2ids'
drop if reminder == 3

** Drop people who saw more than 1 screen during part 1 
** (i.e. people who show up in part 2 data, but not part 1)
drop if _merge == 2

** Add completion dummy
// If the mturkid shows up in part 1 and 2 data, it was completed.
gen completed = (_merge == 3) 

** Drop merge
drop _merge

** Add bonus type
gen high_bonus = inlist(bonus2, 11, 12)

decode source, gen(date)
replace date = substr(date, strpos(date, "/") + 1, .)
replace date = subinstr(date, ")", "", .)
destring date, replace

save "$preppeddata/Experiment 2/FullCompletionData.dta", replace

** Only keep people who weren't top or bottom coded
merge 1:1 mturkid using "$preppeddata/Experiment 2/topbottomcoded.dta"

drop if _merge == 2

drop _merge
keep if no_top_bottom_coding == 1

save "$preppeddata/Experiment 2/CompletionData.dta", replace
