/******************************************************************************

Exp2FinalReg.do

This file generates the final regression tables for experiment 2.

*******************************************************************************/

** Import data — this already has top and bottom-censored
** subjects filtered out
use "$preppeddata/Experiment 2/CompletionData.dta", clear

** Add day part 2 was available
gen part2available = date + delay

** Rename incentive
rename bonus2 incentive

** Create group for part 1 & part 2 dates to use for two-way clustering
egen part1_part2date = group(date part2available)

** Gen log delay
gen log_delay = log(delay)

** Gen extraone
gen extraone = (incentive == 4 | incentive == 12)
label variable extraone "Extra \\$1"

** Add labels
label variable high_bonus "High Incentive"
label variable log_delay "Ln(P2 Delay)"
label variable reminder "Received Reminder"

** Add labels to delay
label define delays_day 2 "2-Day Delay" 7 "1-Week Delay" ///
		21 "3-Week Delay" 42 "6-Week Delay", modify
label values delay delays_day

** Add num participants
count 
local num_participants `r(N)'

** Create regression table, where we regress completing the task
** on whether there was a high incentive, ln(delay)
foreach delaytype in "c.log_delay" "i.delay" {
	if "`delaytype'" == "c.log_delay" local delaytxt "logcont"
	if "`delaytype'" == "i.delay" local delaytxt "categorical"
	
	foreach regtype in "base" "base_extra" "base_remind" "base_interact" "base_FE_clust" ///
		"base_interact_FE_clust" {
				if "`regtype'" == "base"{ 
					local covariates ""
					local options "" 
					local clustered ""
					local FEspec ""
					local regspec "reg"
				}
				else if "`regtype'" == "base_remind"{ 
					local covariates `"c.reminder#c.high_bonus c.reminder#`delaytype'"'
					local options "" 
					local clustered ""
					local FEspec ""
					local regspec "reg"
				}
				else if "`regtype'" == "base_extra"{ 
					local covariates "extraone"
					local options "" 
					local clustered ""
					local FEspec ""
					local regspec "reg"
				}
				else if "`regtype'" == "base_interact" {
					local covariates `"c.reminder#c.high_bonus c.reminder#`delaytype' c.high_bonus#`delaytype' c.reminder#c.high_bonus#`delaytype'"'
					local options "" 
					local clustered ""
					local FEspec ""
					local regspec "reg"
				}
				else if "`regtype'" == "base_FE_clust" {
					local covariates `"c.reminder#c.high_bonus c.reminder#`delaytype'"'
					local options "absorb(date) vce(cluster part1_part2date)" 
					local clustered "X"
					local FEspec "X"
					local regspec "areg"
				}
				else if "`regtype'" == "base_interact_FE_clust" {
					local covariates `"c.reminder#c.high_bonus c.reminder#`delaytype' c.high_bonus#`delaytype' c.reminder#c.high_bonus#`delaytype'"'
					local options "absorb(date) vce(cluster part1_part2date)" 
					local clustered "X"
					local FEspec "X"
					local regspec "areg"
				}
				
				`regspec' completed reminder c.high_bonus `delaytype' `covariates', ///
				`options' baselevels
				eststo `regtype'
				estadd local n_participants `num_participants'
				estadd local typecluster "`clustered'"
				estadd local typefe "`FEspec'"
			}
			
		if "`delaytype'" == "c.log_delay" {
			esttab base base_remind base_interact base_FE_clust ///
			base_interact_FE_clust base_extra ///
						using `"$tables/Experiment 2/completionreg`delaytxt'.tex"', ///
							replace se booktabs nonote nobaselevels numbers b(%8.2f) se(%8.3f)  ///
							mgroups("Completed Part-2 Survey", pattern(1 0 0 0 0) ///
							prefix(\multicolumn{@span}{c}{) suffix(}) span) ///
							nomtitles ///
							star(* 0.10 ** 0.05 *** 0.01) label ///
							stats(N n_participants typecluster typefe, ///
							l("Observations" "Number of Participants" "S.E. Clustered by P1 \& P2 Date" "P1 Date FE") ///
							fmt(%8.0fc %8.2fc %8.0fc))
		}
		
		if "`delaytype'" == "i.delay" {
			esttab base base_remind base_FE_clust ///
						using `"$tables/Experiment 2/completionreg`delaytxt'.tex"', ///
							replace se booktabs nonote nobaselevels numbers b(%8.2f) se(%8.3f)  ///
							mgroups("Completed Part-2 Survey", pattern(1 0 0) ///
							prefix(\multicolumn{@span}{c}{) suffix(}) span) ///
							nomtitles ///
							star(* 0.10 ** 0.05 *** 0.01) label ///
							stats(N n_participants typecluster typefe, ///
							l("Observations" "Number of Participants" "S.E. Clustered by P1 \& P2 Date" "P1 Date FE") ///
							fmt(%8.0fc %8.0fc %8.0fc))
		}
}

********************************************************************************************
use "$preppeddata/Experiment 2/wtp_pooled_exp2.dta", clear

** Only keep people who weren't top or bottom coded
merge m:1 mturkid using "$preppeddata/Experiment 2/topbottomcoded.dta"
drop _merge
keep if no_top_bottom_coding == 1

** Add num participants
count 
local num_participants = `r(N)' / 16

** Rename incentive 
rename payment incentive

** Gen log delay
gen log_delay = log(delay)

** Add labels to delay
label define delays_day 2 "2-Day Delay" 7 "1-Week Delay" ///
		21 "3-Week Delay" 42 "6-Week Delay", modify
label values delay delays_day
	
** Gen high bonus
gen high_bonus = (max_bonus == 12)

** Add labels
label variable high_bonus "High Incentive"
label variable log_delay "Ln(P2 Delay)"
label variable incentive "Extra \\$1"

replace incentive = (incentive == 4 | incentive == 12)

** Get increase in WTP for extra $1 in each incentive group
reg WTP incentive if high_bonus == 0, vce(cluster mturkid)
local wtpincreaselow: di %3.2f _b[incentive]
local wtpincreaselowse: di %9.3f _se[incentive]

reg WTP incentive if high_bonus == 1, vce(cluster mturkid)
local wtpincreasehigh: di %3.2f _b[incentive]
local wtpincreasehighse: di %9.3f _se[incentive]

** Write to Latex
latex_write \wtpincreaselow "`wtpincreaselow'"
latex_write \wtpincreaselowse "`wtpincreaselowse'"
latex_write \wtpincreasehigh "`wtpincreasehigh'"
latex_write \wtpincreasehighse "`wtpincreasehighse'"

** Create indicators for top & bottom censored
gen top_censored = (high_bonus == 0 & WTP == 4.125) | (high_bonus == 1 & WTP == 12.375)
gen bottom_censored = (high_bonus == 0 & WTP == -4.125) | (high_bonus == 1 & WTP == -12.375)

** Create wtp_lower and wtp_upper
gen wtp_lower = WTP if top_censored == 0 & bottom_censored == 0
gen wtp_upper = WTP if top_censored == 0 & bottom_censored == 0

replace wtp_lower = . if bottom_censored == 1
replace wtp_upper = -4 if bottom_censored == 1 & high_bonus == 0
replace wtp_upper = -12 if bottom_censored == 1 & high_bonus == 1

replace wtp_upper = . if top_censored == 1
replace wtp_lower = 4 if top_censored == 1 & high_bonus == 0
replace wtp_lower = 12 if top_censored == 1 & high_bonus == 1

** Add dates
decode source, gen(date)
replace date = substr(date, (strpos(date, "/") + 1), .)
replace date = subinstr(date, ")", "", .)
destring date, replace

** Create regression table, where we regress WTP
** on whether there was a high incentive, ln(delay)

foreach delaytype in "c.log_delay" "i.delay" {
	if "`delaytype'" == "c.log_delay" local delaytxt "logcont"
	if "`delaytype'" == "i.delay" local delaytxt "categorical"
	
	foreach regtype in "base_WTP" "base_WTP_delay" "base_triple" ///
	"base_WTP_FE" "base_triple_FE" "base_WTP_tobit" "base_WTP_delay_tobit" {
				if "`regtype'" == "base_WTP"{ 
					local covariates ""
					local options "vce(cluster mturkid)" 
					local FEspec ""
					local regspec "reg WTP"
				}
				else if "`regtype'" == "base_WTP_delay"{ 
					local covariates `"`delaytype' c.incentive#`delaytype'"'
					local options "vce(cluster mturkid)" 
					local FEspec ""
					local regspec "reg WTP"
				}
				else if "`regtype'" == "base_triple" { 
					local covariates `"`delaytype' c.incentive#`delaytype' c.high_bonus#`delaytype' c.incentive#`delaytype'#c.high_bonus"'
					local options "vce(cluster mturkid)"  
					local FEspec ""
					local regspec "reg WTP"
				}
				else if "`regtype'" == "base_WTP_FE" {
					local covariates ""
					local options "absorb(date) vce(cluster mturkid)" 
					local FEspec "X"
					local regspec "areg WTP"
				}
				else if "`regtype'" == "base_WTP_tobit" {
					local covariates ""
					local options "vce(cluster mturkid)" 
					local FEspec ""
					local regspec "intreg wtp_lower wtp_upper"
				}
				else if "`regtype'" == "base_WTP_delay_tobit" {
					local covariates `"`delaytype' c.incentive#`delaytype'"'
					local options "vce(cluster mturkid)" 
					local FEspec ""
					local regspec "intreg wtp_lower wtp_upper"
				}
				
				`regspec' c.incentive c.high_bonus c.incentive#c.high_bonus ///
				`covariates', `options' baselevels
				eststo `regtype'
				estadd local n_participants `num_participants'
				estadd local typefe "`FEspec'"
				
				if "`delaytype'" == "c.log_delay" & "`regtype'" == "base_WTP" { 
				local lowincentdollarincrease: di %3.0f _b[c.incentive] * 100
				local highincentdollarincrease: di %3.0f ///
					(_b[c.incentive] +  _b[c.incentive#c.high_bonus]) * 100
				local lowincentdollarincreasedol: di %3.2f _b[c.incentive]
				local highincentdollarincreasedol: di %3.2f ///
					(_b[c.incentive] +  _b[c.incentive#c.high_bonus])
			
				latex_write \lowincentdollarincrease "`lowincentdollarincrease'"
				latex_write \highincentdollarincrease "`highincentdollarincrease'"
				latex_write \lowincentdollarincreasedol "`lowincentdollarincreasedol'"
				latex_write \highincentdollarincreasedol "`highincentdollarincreasedol'"
			}
		}
			
		if "`delaytype'" == "c.log_delay" {
			esttab base_WTP base_WTP_delay base_triple base_WTP_FE ///
			base_WTP_tobit base_WTP_delay_tobit ///
						using `"$tables/Experiment 2/WTPreg`delaytxt'.tex"', ///
							replace se nonote nobaselevels numbers b(%8.2f) se(%8.3f)  ///
							mgroups("WTP for Reminders (\\$)", pattern(1 0 0 0 0 0) ///
							prefix(\multicolumn{@span}{c}{) suffix(}) span) ///
							mtitles("OLS" "OLS" "OLS" "OLS" "Tobit" "Tobit") ///
							eqlabels(" " " " " ") unstack drop(lnsigma:) ///
							star(* 0.10 ** 0.05 *** 0.01) label ///
							stats(N n_participants typefe, ///
							l("Observations" "Number of Participants" "P1 Date FE") ///
							fmt(%8.0fc %8.0fc %8.0fc))
		}
		
		if "`delaytype'" == "i.delay" {
			esttab base_WTP base_WTP_delay base_WTP_FE ///
			base_WTP_tobit base_WTP_delay_tobit ///
						using `"$tables/Experiment 2/WTPreg`delaytxt'.tex"', ///
							replace se nonote nobaselevels numbers b(%8.2f) se(%8.3f)  ///
							mgroups("WTP for Reminders (\\$)", pattern(1 0 0 0 0) ///
							prefix(\multicolumn{@span}{c}{) suffix(}) span) ///
							mtitles("OLS" "OLS" "OLS" "Tobit" "Tobit") ///
							eqlabels(" " " " " ") unstack drop(lnsigma:) ///
							star(* 0.10 ** 0.05 *** 0.01) label ///
							stats(N n_participants typefe, ///
							l("Observations" "Number of Participants" "P1 Date FE") ///
							fmt(%8.0fc %8.0fc %8.0fc))
		}
		
}
					
** For the appendix:
** Using column 1 of the table above, use first 2 MPLs, first 4,
** first 6 & first 8

foreach regtype in "first_2" "first_4" "first_6" "first_8" {
			if "`regtype'" == "first_2"{ 
				local condition "counter <= 2" 
				local counter "\(T=2\)"
			}
			else if "`regtype'" == "first_4" {
				local condition "counter <= 4" 
				local counter "\(T=4\)"

			}
			else if "`regtype'" == "first_6" {
				local condition "counter <= 6" 
				local counter "\(T=6\)"
			}
			else if "`regtype'" == "first_8" {
				local condition "counter <= 8" 
				local counter "\(T=8\)"
			}
			
			reg WTP c.incentive c.high_bonus c.incentive#c.high_bonus ///
			if `condition', vce(cluster mturkid)
			
			eststo `regtype'
			estadd local n_participants `num_participants'
			estadd local MPLcount "`counter'"
		}
		
	esttab first_2 first_4 first_6 first_8 ///
				using `"$tables/Experiment 2/byMPLWTPreg.tex"', ///
					replace se nonote nobaselevels numbers b(%8.2f) se(%8.3f)  ///
					mgroups("WTP for Reminders (\\$)", pattern(1 0 0 0) ///
					prefix(\multicolumn{@span}{c}{) suffix(}) span) ///
					nomtitles ///
					star(* 0.10 ** 0.05 *** 0.01) label ///
					stats(N n_participants MPLcount, ///
					l("Observations" "Number of Participants" "First \$T\$ MPLs") ///
					fmt(%8.0fc %8.0fc %8.0fc))

					
** Create regression table only for the 90% kept in completion data
** Create regression table, where we regress WTP
** on whether there was a high incentive, ln(delay)

merge m:1 mturkid using "$preppeddata/Experiment 2/CompletionData.dta"
keep if _merge == 3

** Add num participants
count 
local num_participants = `r(N)' / 16

foreach delaytype in "c.log_delay" {
	if "`delaytype'" == "c.log_delay" local delaytxt "logcont"
	
	foreach regtype in "base_WTP" "base_WTP_delay" "base_triple" ///
	"base_WTP_FE" "base_triple_FE" "base_WTP_tobit" "base_WTP_delay_tobit" {
		if "`regtype'" == "base_WTP"{ 
			local covariates ""
			local options "vce(cluster mturkid)" 
			local FEspec ""
			local regspec "reg WTP"
		}
		else if "`regtype'" == "base_WTP_delay"{ 
			local covariates `"`delaytype' c.incentive#`delaytype'"'
			local options "vce(cluster mturkid)" 
			local FEspec ""
			local regspec "reg WTP"
		}
		else if "`regtype'" == "base_triple" { 
			local covariates `"`delaytype' c.incentive#`delaytype' c.high_bonus#`delaytype' c.incentive#`delaytype'#c.high_bonus"'
			local options "vce(cluster mturkid)"  
			local FEspec ""
			local regspec "reg WTP"
		}
		else if "`regtype'" == "base_WTP_FE" {
			local covariates ""
			local options "absorb(date) vce(cluster mturkid)" 
			local FEspec "X"
			local regspec "areg WTP"
		}
		else if "`regtype'" == "base_WTP_tobit" {
			local covariates ""
			local options "vce(cluster mturkid)" 
			local FEspec ""
			local regspec "intreg wtp_lower wtp_upper"
		}
		else if "`regtype'" == "base_WTP_delay_tobit" {
			local covariates `"`delaytype' c.incentive#`delaytype'"'
			local options "vce(cluster mturkid)" 
			local FEspec ""
			local regspec "intreg wtp_lower wtp_upper"
		}
				
			`regspec' c.incentive c.high_bonus c.incentive#c.high_bonus ///
			`covariates', `options' baselevels
			eststo `regtype'
			estadd local n_participants `num_participants'
			estadd local typefe "`FEspec'"
		}
			
		esttab base_WTP base_WTP_delay base_triple base_WTP_FE ///
		base_WTP_tobit base_WTP_delay_tobit ///
			using `"$tables/Experiment 2/WTPreg`delaytxt'_90pct.tex"', ///
			replace se nonote nobaselevels numbers b(%8.2f) se(%8.3f)  ///
			mgroups("WTP for Reminders (\\$)", pattern(1 0 0 0 0 0) ///
			prefix(\multicolumn{@span}{c}{) suffix(}) span) ///
			mtitles("OLS" "OLS" "OLS" "OLS" "Tobit" "Tobit") ///
			eqlabels(" " " " " ") unstack drop(lnsigma:) ///
			star(* 0.10 ** 0.05 *** 0.01) label ///
			stats(N n_participants typefe, ///
			l("Observations" "Number of Participants" "P1 Date FE") ///
			fmt(%8.0fc %8.0fc %8.0fc))
}	
