/******************************************************************************

Exp2RiskAversionCalibration.do

This file generates the numbers for Appendix E. 

*******************************************************************************/

** CARA 
** Get WTP and save as a temp file
use "$preppeddata/Experiment 2/wtp_pooled_exp2.dta", clear
merge m:1 mturkid using "$preppeddata/Experiment 2/topbottomcoded.dta"
drop _merge
keep if no_top_bottom_coding == 1

** Keep relevant variables and collapse
keep payment delay WTP
drop if payment == 4 | payment == 12
collapse (mean) WTP, by (payment delay)

** Rename variables
gen high_bonus = (payment == 11)
drop payment
rename WTP w

** Save data
tempfile exp2WTP
save "`exp2WTP'"

** Get completion data, merge with WTP
use "$preppeddata/Experiment 2/CompletionData.dta", clear
rename bonus2 incentive

** Only keep people who weren't top or bottom coded
merge m:1 mturkid using "$preppeddata/Experiment 2/topbottomcoded.dta"
drop if _merge == 2
drop _merge
keep if no_top_bottom_coding == 1

gen pi_0 = .
gen pi_1 = .

** Store the probability that the task is completed with and without BE
foreach remindertype in 0 1 {
	foreach bonustype in 0 1 {
		foreach delaytype in 2 7 21 42 {
			local condition "high_bonus == `bonustype' & delay == `delaytype' & reminder == `remindertype'"
			mean completed if `condition'
			
			if `remindertype' == 0 replace pi_0 = r(table)[1,1] ///
				if high_bonus == `bonustype' & delay == `delaytype'
			if `remindertype' == 1 replace pi_1 = r(table)[1,1] ///
				if high_bonus == `bonustype' & delay == `delaytype'
		}
	}
}

** Condense data set
keep delay high_bonus pi_0 pi_1
duplicates drop
sort high_bonus delay

** Add r
gen r = 3 if high_bonus == 0
replace r = 11 if high_bonus == 1

** Merge
merge 1:1 delay high_bonus using `exp2WTP'
drop _merge

** Calculate effects using given alphas
local i = 0 // index, sorted by size

foreach alph in 0 0.00019 0.000325 0.0007 0.00087 0.0019 0.002 0.03 0.2 {
	gen alph_`i' = (pi_1 * exp(-`alph' * r) - pi_0 * exp(-`alph' * r)) ///
			/ (pi_0 * exp(-`alph'*(w+r)) + (1-pi_0)*exp(-`alph' * w))
	di "Alpha `i' = `alph'"
	local i = `i' + 1
}

** Write to latex
foreach i of numlist 0/8 {
	if `i' == 0 local alph "zero"
	if `i' == 1 local alph "I"
	if `i' == 2 local alph "II"
	if `i' == 3 local alph "III"
	if `i' == 4 local alph "IV"
	if `i' == 5 local alph "V"
	if `i' == 6 local alph "VI"
	if `i' == 7 local alph "VII"
	if `i' == 8 local alph "VIII"
	
	foreach bonustype in 0 1 {
		if `bonustype' == 0 local incent "Lo"
		if `bonustype' == 1 local incent "Hi"
		
		foreach delaytype in 2 7 21 42 {
			if `delaytype' == 2 local time "Twodays"
			if `delaytype' == 7 local time "Oneweek"
			if `delaytype' == 21 local time "Threeweeks"
			if `delaytype' == 42 local time "Sixweeks"
			
			di "alpha: `i', delay: `delaytype', high_bonus: `bonustype'"
			levelsof alph_`i' if delay == `delaytype' & high_bonus == `bonustype', ///
				local(val)
			local val : di %3.2f  `val'
			di `val'

			latex_write incent`incent'`time'Alph`alph' "`val'"
		}
	}
}

** CRRA

** Calculate effects using given rho and z
local i = 1 // index, sorted by size

foreach rho in 0 1.37 {
	if `rho' == 0 {
		gen rhoz_0 = (pi_1 - pi_0) 
		di "RhoZ 0 = `rho', `z'"
	}
	else {
		foreach z in 10 100 1000 100000 {
			
			gen rhoz_`i' = (pi_1 - pi_0)  ///
				/ (pi_0 * ((`z' + r) / (`z' + w + r))^`rho' + (1-pi_0) * ((`z' + r) / (`z' + w))^`rho')
			di "RhoZ `i' = `rho', `z'"
			local i = `i' + 1
		}
	}
}

** Write to latex
foreach i of numlist 0/4 {
	if `i' == 0 local rhoz "zero"
	if `i' == 1 local rhoz "I"
	if `i' == 2 local rhoz "II"
	if `i' == 3 local rhoz "III"
	if `i' == 4 local rhoz "IV"
	
	foreach bonustype in 0 1 {
		if `bonustype' == 0 local incent "Lo"
		if `bonustype' == 1 local incent "Hi"
		
		foreach delaytype in 2 7 21 42 {
			if `delaytype' == 2 local time "Twodays"
			if `delaytype' == 7 local time "Oneweek"
			if `delaytype' == 21 local time "Threeweeks"
			if `delaytype' == 42 local time "Sixweeks"
			
			di "rhoz: `i', delay: `delaytype', high_bonus: `bonustype'"
			levelsof rhoz_`i' if delay == `delaytype' & high_bonus == `bonustype', ///
				local(val)
			local val : di %3.2f  `val'
			di `val'

			latex_write incent`incent'`time'Rhoz`rhoz' "`val'"
		}
	}
}

** Generate empirical estimates
use "$preppeddata/Experiment 2/wtp_pooled_exp2.dta", clear

** Only keep people who weren't top or bottom coded
merge m:1 mturkid using "$preppeddata/Experiment 2/topbottomcoded.dta"
drop _merge
keep if no_top_bottom_coding == 1

gen high_bonus = inlist(payment, 11, 12)

foreach bonustype in 0 1 {
	if `bonustype' == 0 local incent "Lo"
	if `bonustype' == 1 local incent "Hi"
	
	foreach delaytype in 2 7 21 42 {
		if `delaytype' == 2 local time "Twodays"
		if `delaytype' == 7 local time "Oneweek"
		if `delaytype' == 21 local time "Threeweeks"
		if `delaytype' == 42 local time "Sixweeks"
		
		reg WTP payment if high_bonus == `bonustype' ///
		& delay == `delaytype', vce(cluster source)
		
		local val : di %3.2f  r(table)[1,1]

		latex_write incent`incent'`time' "`val'"
		}
}
