/******************************************************************************

Exp2SummaryAnalysis.do

This file runs summary stats from the Experiment 2.

*******************************************************************************/

** Load data
local filename_wtp "wtp_pooled_exp2.dta"

use "$preppeddata/Experiment 2/`filename_wtp'", clear

local marker "pooled" 
local text_only_marker "pooled"
local text_position -0.10
count
local num_participants r(N)/16

** Count top and bottom censored by responses before we drop censored people
gen high_incentive = (max_bonus == 12)
foreach x of numlist 0 1 {
	if `x' == 0 local incentive "low"
	if `x' == 1 local incentive "high"
		
	count if high_incentive == `x'
	scalar num_responses = r(N)
		
	count if choice == "0left" & high_incentive == `x'
	scalar num_top = r(N)
		
	count if choice == "33left" & high_incentive == `x'
	scalar num_bottom = r(N)
		
	scalar pct_top_censored = (num_top / num_responses) * 100
	scalar pct_bottom_censored = (num_bottom / num_responses) * 100
		
	local top_censored: di %3.2f scalar(pct_top_censored)
	local bottom_censored: di %3.2f scalar(pct_bottom_censored)
		
	latex_write `incentive'topcensored "`top_censored'"
	latex_write `incentive'bottomcensored "`bottom_censored'"
		
}

*******************************************************************************	
** Merge to drop bottom and top coded people
merge m:1 mturkid using "$preppeddata/Experiment 2/topbottomcoded.dta"
drop _merge
keep if no_top_bottom_coding == 1


	** Summary stats
	
	** Mean WTP by incentive 
	** Mean WTP for each combination of delay & incentive
	foreach x of numlist 3 4 11 12 {
		if `x' == 3 local x_written "\three"
		if `x' == 4 local x_written "\four"
		if `x' == 11 local x_written "\eleven"
		if `x' == 12 local x_written "\twelve"
			
		mean WTP if payment == `x'
		matrix store_results = r(table)
		local mean : di %3.2f store_results[1,1]
		local sd : di %9.3f store_results[2,1]
		latex_write `x_written'dollar`text_only_marker' "`mean'"
		latex_write `x_written'dollar`text_only_marker'sd "`sd'"
		}
	
	** Mean WTP for each combination of delay & incentive
	foreach x of numlist 3 4 11 12 {
		foreach y of numlist 2 7 21 42 {
			if `x' == 3 local x_written "\three"
			if `x' == 4 local x_written "\four"
			if `x' == 11 local x_written "\eleven"
			if `x' == 12 local x_written "\twelve"
			
			if `y' == 2 local time "twodays"
			if `y' == 7 local time "oneweek"
			if `y' == 21 local time "threeweeks"
			if `y' == 42 local time "sixweeks"
			
			mean WTP if payment == `x' & delay == `y'
			matrix store_results = r(table)
			local mean : di %3.2f store_results[1,1]
			local sd : di %9.3f store_results[2,1]
			latex_write `x_written'dollar`time'`text_only_marker' "`mean'"
			latex_write `x_written'dollar`time'`text_only_marker'sd "`sd'"
		}
	}

	** Count use of the 1-left strategy 
	** % who use 1 left at least once, use 1 left in at least 25% of MPLs, 
	** at least 50% of MPLs, at least 75% of MPLs and 100% of MPLs
	
	** NOTE: this is long data, not wide, so we need to divide by 16 
	** before we divide by participants.
	
	foreach x of numlist 1 4 8 12 16 {
		if `x' == 1 local x_written "once"
		if `x' == 4 local x_written "ptwentyfive"
		if `x' == 8 local x_written "pfifty"
		if `x' == 12 local x_written "pseventyfive"
		if `x' == 16 local x_written "all"
			
		count if times_1left >= `x'
		scalar oneleftatleast`x' = r(N) / 16
		scalar oneleftatleast`x' = (oneleftatleast`x' / `num_participants') * 100
		local oneleftatleast`x': di %3.2f scalar(oneleftatleast`x')
		latex_write oneleftatleast`x_written'`text_only_marker' "`oneleftatleast`x''"
		
	}
 
	** Count always want reminders vs never want reminders, by incentive level
	** Save to numbers.tex and drop

	foreach x of numlist 3 4 11 12 {
		foreach i of numlist 0 33 {
			gen strategy_`i'left_`x' = (choice == "`i'left" & payment == `x')
			egen times_`i'left_`x' = total(strategy_`i'left_`x'), by(mturkid)
			drop strategy_`i'left_`x'
			gen always_`i'left_`x' = (times_`i'left_`x' == 4)
			drop times_`i'left_`x'
			
			if `i' == 0 { //i.e. 0 left — always want reminders
				gen always_reminders_`x' = always_`i'left_`x'
			}
			
			if `i' == 33 {
				gen never_reminders_`x' = always_`i'left_`x'
			}
			drop always_`i'left_`x'
			}
			count if always_reminders_`x' == 1
			scalar always_`x' = r(N) / 16
			scalar pct_always_`x' = (always_`x' / `num_participants') * 100
			local pct_always_`x': di %3.2f scalar(pct_always_`x')
			
			count if never_reminders_`x' == 1
			scalar never_`x' = r(N) / 16
			scalar pct_never_`x' = (never_`x' / `num_participants') * 100
			local pct_never_`x': di %3.2f scalar(pct_never_`x')
			
			if `x' == 3 local x_written "three"
			if `x' == 4 local x_written "four"
			if `x' == 11 local x_written "eleven"
			if `x' == 12 local x_written "twelve"
			
			latex_write sharealwaysreminders`x_written'`text_only_marker' "`pct_always_`x''"
			latex_write shareneverreminders`x_written'`text_only_marker' "`pct_never_`x''"
			
			drop always_reminders_`x' never_reminders_`x'
	}

	** Spike plot of mean WTPs by delay & incentive
	local varname WTP
	local group1 delay
	local group2 payment
	collapse (mean) y = `varname' (semean) se_y = `varname', by(`group1' `group2')

	sort `group1' `group2'
	gen x = _n
	replace x = _n + 2 if _n >= 5
	replace x = _n + 4 if _n >= 9
	replace x = _n + 6 if _n >= 13

	gen yu = y + 1.96*se_y
	gen yl = y - 1.96*se_y

	separate y, by(`group2')
	separate yu, by(`group2')
	separate yl, by(`group2')

	twoway (scatter y3 x, msymbol(square) color(navy)) ///
		   (rspike yu3 yl3 x, color(navy))  ///
		   (scatter y4 x , msymbol(square) color(maroon)) ///
		   (rspike yu4 yl4 x, color(maroon) )  ///
		   (scatter y11 x , msymbol(square) color(dkgreen)) ///
		   (rspike yu11 yl11 x, color(dkgreen))  ///
		   (scatter y12 x , msymbol(square) color(dkorange)) ///
		   (rspike yu12 yl12 x, color(dkorange)), scheme(s1color) ///
		   xlabel(none) xtitle(" ") b2("Part-2 Delay") /// 
		   ytitle("Willingness To Pay For Reminders ($)") yline(0, lpattern(dash) lcolor(black)) ///
		   xline(5.5,  lwidth(thin) lcolor(dimgray)) ///
		   xline(11.5,  lwidth(thin) lcolor(dimgray)) ///
		   xline(17.5,  lwidth(thin) lcolor(dimgray)) ///
		   text(`text_position' 2 "2 Day", place(e)) ///
		   text(`text_position' 7.5 "1 Week", place(e)) ///
		   text(`text_position' 13 "3 Weeks", place(e)) ///
		   text(`text_position' 18.5 "6 Weeks", place(e)) ///
		   legend(order(1 "$3 Incentive" 3 "$4 Incentive" ///
		   5 "$11 Incentive" 7 "$12 Incentive") position(3) bplacement(neast) ///
		   region(lstyle(none)) row(4) size(small)) ylabel(0(0.5)2)
		   
	graph export `"$figures/Experiment 2/SpikePlot`marker'.pdf"', replace

	
 ***********************************************************
 
local filename_dem "pooled_exp2_demographic.dta" // "pilot1_exp2_demographic.dta"
use "$preppeddata/Experiment 2/`filename_dem'", clear

** Merge to drop bottom and top coded people
merge 1:1 mturkid using "$preppeddata/Experiment 2/topbottomcoded.dta"
drop _merge
keep if no_top_bottom_coding == 1

local marker "pooled" 
local text_only_marker "pooled"

** Mean, median, 25th, 75th percentile time completion

foreach stat in "mean" "p25" "p50" "p75" {
	
	if "`stat'" == "mean" local statlabel "mean"
	if "`stat'" == "p25" local statlabel "ptwentyfive"
	if "`stat'" == "p50" local statlabel "pfifty"
	if "`stat'" == "p75" local statlabel "pseventyfive"
		
	sum durationinseconds, detail
	local value : di %3.2f r(`stat')
	latex_write \time`statlabel'`text_only_marker' "`value'"
}

** Mean, median, 25th, 75th percentile age
sum age, detail

foreach stat in "mean" "p25" "p50" "p75" {
	local value : di %3.2f r(`stat')
	
	if "`stat'" == "mean" local statlabel "mean"
	if "`stat'" == "p25" local statlabel "ptwentyfive"
	if "`stat'" == "p50" local statlabel "pfifty"
	if "`stat'" == "p75" local statlabel "pseventyfive"
	
	latex_write \age`statlabel'`text_only_marker' "`value'"
}

