/******************************************************************************

GenerateIncentiveReminderFigure.do

This file creates Figure 4.

*******************************************************************************/
use "$preppeddata/Experiment 2/CompletionData.dta", clear
rename bonus2 incentive

** Only keep people who weren't top or bottom coded
merge m:1 mturkid using "$preppeddata/Experiment 2/topbottomcoded.dta"
drop if _merge == 2
drop _merge
keep if no_top_bottom_coding == 1

gen ptestimate_remind = .
gen stderror_remind = .

foreach bonustype in 0 1 {
	foreach delaytype in 2 7 21 42 {
		
		reg completed reminder if high_bonus == `bonustype' ///
		& delay == `delaytype', vce(cluster source)
		replace ptestimate_remind = r(table)[1,1] if high_bonus == `bonustype' & delay == `delaytype'
		replace stderror_remind = r(table)[2,1] if high_bonus == `bonustype' & delay == `delaytype'
		}
}

duplicates drop high_bonus delay, force

gen yu_reminder = ptestimate_remind + 1.96*stderror_remind
gen yl_reminder = ptestimate_remind - 1.96*stderror_remind

keep high_bonus delay ptestimate_remind stderror_remind yu_remind yl_remind 

rename ptestimate_remind remindereffect

save "$preppeddata/Experiment 2/grouped_remindereffect.dta", replace

use "$preppeddata/Experiment 2/wtp_pooled_exp2.dta", clear

** Only keep people who weren't top or bottom coded
merge m:1 mturkid using "$preppeddata/Experiment 2/topbottomcoded.dta"
drop _merge
keep if no_top_bottom_coding == 1

gen high_bonus = inlist(payment, 11, 12)

gen ptestimate_pay = .
gen stderror_pay = .

foreach bonustype in 0 1 {
	if `bonustype' == 0 local incent "Lo"
	if `bonustype' == 1 local incent "Hi"
	
	foreach delaytype in 2 7 21 42 {
		if `delaytype' == 2 local time "Twodays"
		if `delaytype' == 7 local time "Oneweek"
		if `delaytype' == 21 local time "Threeweeks"
		if `delaytype' == 42 local time "Sixweeks"
		
		reg WTP payment if high_bonus == `bonustype' ///
		& delay == `delaytype', vce(cluster source)
		replace ptestimate_pay = r(table)[1,1] if high_bonus == `bonustype' & delay == `delaytype'
		replace stderror_pay = r(table)[2,1] if high_bonus == `bonustype' & delay == `delaytype'
		}
}

gen yu_pay = ptestimate_pay + 1.96*stderror_pay
gen yl_pay = ptestimate_pay - 1.96*stderror_pay

duplicates drop delay high_bonus, force
keep delay high_bonus ptestimate_pay stderror_pay yu yl
drop if ptestimate_pay == .

merge m:1 high_bonus delay using "$preppeddata/Experiment 2/grouped_remindereffect.dta"
drop _merge

save "$preppeddata/Experiment 2/grouped_remindereffect_WTPincent.dta", replace   
	

gen group = 1 if high_bonus == 0 & delay == 2
replace group = 2 if high_bonus == 0 & delay == 7
replace group = 3 if high_bonus == 0 & delay == 21
replace group = 4 if high_bonus == 0 & delay == 42
replace group = 5 if high_bonus == 1 & delay == 2
replace group = 6 if high_bonus == 1 & delay == 7
replace group = 7 if high_bonus == 1 & delay == 21
replace group = 8 if high_bonus == 1 & delay == 42

so remindereffect

gen x = _n

label variable ptestimate_pay "Effect of Incentive on WTP"
label variable remindereffect "Effect of Reminder on Completion"

// I'll use lfit, but want to report the coefficients so I'll run the reg
// and save the values in locals
reg ptestimate_pay remindereffect

// Add the constant to our tex commands
local constant: di  %3.2f _b[_cons]
latex_write \bestfitconstant "`constant'"

// Add the slope to our tex commands
local slope: di %3.2f _b[remindereffect]
latex_write \bestfitslope "`slope'"

twoway (rspike yu_pay yl_pay remindereffect, color(dknavy)) ///
		   (scatter ptestimate_pay remindereffect, msymbol(square) color(dknavy)) ///
		   (lfit ptestimate_pay remindereffect, lcolor(maroon)) ///
		   (function y=x, range(-0.25 0.5) lpattern(dash) lcolor(gs8)), ///
		   scheme(s1color) xtitle("Effect of Reminder on Completion") /// 
		   ytitle("Effect of Extra $1 Incentive on WTP") yline(0, lpattern(dash) lcolor(gs8)) ///
		   text(.1726 -.1235  "High Incentive," "2 Day", size(vsmall) place(e)) ///
		   text(.228 .11 "High Incentive," "1 Week", size(vsmall) place(e)) ///
		   text(-.138 .165 "High Incentive," "3 Week", size(vsmall) place(e)) ///
		   text(-.138 .33 "High Incentive," "6 Week", size(vsmall) place(e)) ///
		   text(.133 .1758 "Low Incentive," "2 Day", size(vsmall) place(e)) ///
		   text(.176 .26 "Low Incentive," "1 Week", size(vsmall) place(e)) ///
		   text(.147 .369 "Low Incentive," "3 Week", size(vsmall) place(e)) ///
		   text(.000 .235 "Low Incentive," "6 Week", size(vsmall) place(e)) ///
		   xlabel(-0.25(0.125)0.5) ylabel(-0.25(0.125)0.5) legend(off)

graph export `"$figures/Experiment 2/Completion WTP.pdf"', replace
