/******************************************************************************

Exp3AddtlBuild.do

This file builds another prepped data file for experiment 3 and must be run
after the summary analysis.

*******************************************************************************/
local source "launch"
** Import data
use `"$preppeddata/Experiment 3/wtp_exp3_`source'.dta"', clear

** Drop unnecessary variables
drop choice choicenum times_1left

** Merge in group types and average times for easy & hard tasks by block
foreach block in 1 2 {
	merge m:1 prolific_id using ///
		`"$preppeddata/Experiment 3/wtp_exp3_avgtimes_block`block'"'
	drop _merge
	
	merge m:1 prolific_id using ///
		`"$preppeddata/Experiment 3/wtp_exp3_grouptype_block`block'"'
	drop _merge
}

** Merge in other sample indicators
merge m:1 prolific_id using `"$preppeddata/Experiment 3/sample_restricted_indicators.dta"'
drop _merge

** Get indicators for top and bottom censored in each block
gen top_censored = (WTP == 4.125)
gen bottom_censored = (WTP == -4.125)

** Sum number per block
egen total_top_censored_b1 = sum(top_censored) if block == 1, by(prolific_id)
egen total_top_censored_b2 = sum(top_censored) if block == 2, by(prolific_id)
egen total_bottom_censored_b1 = sum(bottom_censored) if block == 1, by(prolific_id)
egen total_bottom_censored_b2 = sum(bottom_censored) if block == 2, by(prolific_id)

** Create indicators
gen block1topcensored = (total_top_censored_b1 == 3)
gen block2topcensored = (total_top_censored_b2 == 3)
gen block1bottomcensored = (total_bottom_censored_b1 == 3)
gen block2bottomcensored = (total_bottom_censored_b2 == 3)

** Drop unnecessary variables
drop top_censored bottom_censored total_top_censored_b1 total_top_censored_b2 ///
	total_bottom_censored_b1 total_bottom_censored_b2

save `"$preppeddata/Experiment 3/final_wtp_exp3.dta"', replace

** Keep all of our new indicators to merge with other WTP data
keep prolific_id durationinseconds bottom90fullpct middle80taskpct ///
	block1easyavgtime block1hardavgtime block1increasing block1allequal ///
	block1decreasing block1nonmonotonic block2easyavgtime block2hardavgtime ///
	block2increasing block2allequal block2decreasing block2nonmonotonic ///
	ever_extreme ever_decrease decrease2ormore block1topcensored ///
	block2topcensored block1bottomcensored block2bottomcensored ///
	block1_ever_extreme block2_ever_extreme ///
	block1pctcorrecteasy block1pctcorrecthard ///
	block2pctcorrecteasy block2pctcorrecthard

duplicates drop prolific_id, force

merge 1:m prolific_id using `"$preppeddata/Experiment 3/wtp_incentiveblock_exp3_launch.dta"'
drop _merge
save `"$preppeddata/Experiment 3/final_wtp_incentiveblock_pair_exp3.dta"', replace
