/******************************************************************************

Exp3BuildLaunch.do

This file prepares data from the Experiment 3 launch of 
the Pay to Plan project.

*******************************************************************************/

** Add local tag
local source "launch"

use "$rawdata/Experiment 3/Experiment 3 Data", clear

** Drop if browser specification not met
drop if !inlist(browser_verification_browser, "Chrome", "Firefox")

** Count before dropping for attention checks
count
local predropcount `r(N)'

** Drop if Captcha failed
drop if !(captcha_entry == "T2YKA" | captcha_retry == "T2YKA") 

** Drop if failed attention check questions
drop if !(strpos(mpl_q1_t1, "left") | strpos(mpl_q1_t2, "left"))
drop if !(strpos(mpl_q2_t1, "right") | strpos(mpl_q2_t2, "right"))

** Drop people who failed the MPL attention checks
drop if xnorm_0choicefinal != ""
drop xnorm_0choicefinal

** Count after dropping for attention checks
count
local postdropcount `r(N)'

** Calculate # dropped
local attnchkdropexpthree = `predropcount' - `postdropcount'
latex_write \attnchkdropexpthree "`attnchkdropexpthree'"

** Destring
destring taskcounter treatment durationinseconds ///
	q_?numequations q_??numequations ///
	q_?percentcorrect q_??percentcorrect q_?correct ///
	q_??correct num10 num100 numeasydiscern numharddiscern, replace

** Drop if missing any task data or choice data

** Two groups of people who are missing task or choice data:
** 1. Left survey early

local left_early = 0 `r(N_drop)'

foreach i of varlist q_* {
	drop if missing(`i') & age == ""
	local left_early = `left_early' + `r(N_drop)'
}

foreach j of varlist xnorm_?choicefinal {
	drop if missing(`j') & age == ""
	local left_early = `left_early' + `r(N_drop)'
}

** 2. Technical problem

local technical_drop = 0
foreach v of varlist q_* {
	drop if missing(`v') & age != ""
	local technical_drop = `technical_drop' + `r(N_drop)'
}

foreach j of varlist xnorm_?choicefinal {
	drop if missing(`j') & age != ""
	local technical_drop = `technical_drop' + `r(N_drop)'
}

latex_write \technicaldropexpthree "`technical_drop'"

save `"$preppeddata/Experiment 3/wtp_allparticipants.dta"', replace

preserve
run "$do/Experiment 3/Build/Exp3SampleRestriction.do"
restore

** Only keep people who are not in the ever_extreme group
merge m:1 prolific_id using `"$preppeddata/Experiment 3/ever_extreme_indicator.dta"'
keep if ever_extreme == 0 
drop _merge

** Add indicator to drop top 10% fastest task 
gen bottom90fullpct = .

sum durationinseconds if treatment == 1, detail
if treatment == 1 replace bottom90fullpct = (durationinseconds < r(p90))

sum durationinseconds if treatment == 2, detail
if treatment == 2 replace bottom90fullpct = (durationinseconds < r(p90))

** Generate pct difference between hard and easy tasks in each block
** Need to count number of each type and number of each type correct in each block

** Initalize values
foreach block in 1 2 {
	
	if `block' == 1 local blockmarker "block1"
	if `block' == 2 local blockmarker "block2"
	
	gen `blockmarker'num10 = 0
	gen `blockmarker'num100 = 0
	gen `blockmarker'numeasydiscern = 0
	gen `blockmarker'numharddiscern = 0

	gen `blockmarker'num10correct = 0
	gen `blockmarker'num100correct = 0
	gen `blockmarker'numeasydiscerncorrect = 0
	gen `blockmarker'numharddiscerncorrect = 0
}

** Check each task and add 1 to the count if it matches the desired condition
forvalues i = 1/14 {

	if `i' <= 7 local blockmarker "block1"
	if `i' > 7 local blockmarker "block2"
	
	// Easy length
	replace `blockmarker'num10 = `blockmarker'num10 + 1 if q_`i'numequations == 10 
		
	replace `blockmarker'num10correct = `blockmarker'num10correct + 1 if q_`i'correct == 1 & ///
	q_`i'numequations == 10
		
	// Hard length
	replace `blockmarker'num100 = `blockmarker'num100 + 1 if q_`i'numequations == 100 
		
	replace `blockmarker'num100correct = `blockmarker'num100correct + 1 if q_`i'correct == 1 & ///
	q_`i'numequations == 100 
		
	// Easy discern
	replace `blockmarker'numeasydiscern = `blockmarker'numeasydiscern + 1 if ///
	q_`i'percentcorrect == 0.95 | q_`i'percentcorrect == 0.05
		
	replace `blockmarker'numeasydiscerncorrect = `blockmarker'numeasydiscerncorrect + 1 if ///
	(q_`i'percentcorrect == 0.95 | q_`i'percentcorrect == 0.05) & q_`i'correct == 1 
		
	// Hard discern
	replace `blockmarker'numharddiscern = `blockmarker'numharddiscern + 1 if ///
	q_`i'percentcorrect == 0.6 | q_`i'percentcorrect == 0.4
		
	replace `blockmarker'numharddiscerncorrect = `blockmarker'numharddiscerncorrect + 1 if ///
	(q_`i'percentcorrect == 0.6 | q_`i'percentcorrect == 0.4) & q_`i'correct == 1
}
foreach block in 1 2 {
	
	if `block' == 1 local blockmarker "block1"
	if `block' == 2 local blockmarker "block2"
	
	** Generate percentages correct for the task types
	gen `blockmarker'pctcorrect10 = `blockmarker'num10correct / `blockmarker'num10 
	gen `blockmarker'pctcorrect100 = `blockmarker'num100correct / `blockmarker'num100
	gen `blockmarker'pctcorrecteasydiscern = `blockmarker'numeasydiscerncorrect / `blockmarker'numeasydiscern
	gen `blockmarker'pctcorrectharddiscern = `blockmarker'numharddiscerncorrect / `blockmarker'numharddiscern

	** Categorize into easy and hard by treatment
	gen `blockmarker'pctcorrecteasy = `blockmarker'pctcorrect10 if treatment == 1
	replace `blockmarker'pctcorrecteasy = `blockmarker'pctcorrecteasydiscern if treatment == 2
	
	gen `blockmarker'pctcorrecthard = `blockmarker'pctcorrect100 if treatment == 1
	replace `blockmarker'pctcorrecthard = `blockmarker'pctcorrectharddiscern if treatment == 2
	
	** Generate pct diff using length if the treatment is 1
	gen `blockmarker'pctdiff = `blockmarker'pctcorrect10 - `blockmarker'pctcorrect100 if treatment == 1

	** Generate pct diff using discernibility if the treatment is 2
	replace `blockmarker'pctdiff = `blockmarker'pctcorrecteasydiscern - `blockmarker'pctcorrectharddiscern ///
	if treatment == 2
	
	** Drop variables used in calculation
	drop `blockmarker'num10correct `blockmarker'num100correct `blockmarker'numeasydiscerncorrect ///
	`blockmarker'numharddiscerncorrect `blockmarker'pctcorrect10 `blockmarker'pctcorrect100 ///
	`blockmarker'pctcorrecteasydiscern `blockmarker'pctcorrectharddiscern
}

** Will create task-level data; save intermediate to create WTP
** data after

save `"$preppeddata/Experiment 3/wtp_intermediate_pooled_exp3_`source'.dta"', replace

** Keep relevant variables — q variables are about tasks 
keep prolific_id q_?time q_?computerselect q_?correct q_?percentcorrect ///
	q_?numequations q_??time q_??computerselect q_??correct q_??percentcorrect ///
	q_??numequations chosenincentiveblock1 chosenincentiveblock2 treatment ///
	bottom90fullpct block1pctdiff block2pctdiff feedback
	
** Reshape
reshape long q_@time q_@computerselect q_@correct q_@numequations q_@percentcorrect, i(prolific_id) j(counter)

** Create indicators for block
gen block = 1 if counter <= 7
replace block = 2 if counter > 7

** Drop
drop if counter == 0

destring q_time q_computerselect q_correct q_numequations q_percentcorrect ///
chosenincentiveblock1 chosenincentiveblock2 treatment, replace
replace q_percentcorrect = round(q_percentcorrect, 0.01)

gen payment = chosenincentiveblock1 if counter <= 7
replace payment = chosenincentiveblock2 if counter > 7

** Create indicators for easy discern and length
gen easy_discern = !(q_percentcorrect == 0.6 | q_percentcorrect == 0.4)
gen easy_length = !(q_numequations == 100)

** Generate average times for hard and easy tasks in each block
foreach block in 1 2 {
	preserve
	keep if block == `block'
	
	gen block`block'easyavgtime = .
	gen block`block'hardavgtime = .
	
	// Treatment in which people choose length
	ereplace block`block'easyavgtime = mean(q_time) ///
		if treatment == 1 & easy_length == 1, by(prolific_id)
	
	ereplace block`block'hardavgtime = mean(q_time) ///
		if treatment == 1 & easy_length == 0, by(prolific_id)
	
	// Treatment in which people choose discernibility
	ereplace block`block'easyavgtime = mean(q_time) ///
		if treatment == 2 & easy_discern == 1, by(prolific_id)
	
	ereplace block`block'hardavgtime = mean(q_time) ///
		if treatment == 2 & easy_discern == 0, by(prolific_id)
	
	keep prolific_id block`block'easyavgtime block`block'hardavgtime
	duplicates drop prolific_id block`block'easyavgtime block`block'hardavgtime, force
	
	replace block`block'easyavgtime = 0 if block`block'easyavgtime == .
	replace block`block'hardavgtime = 0 if block`block'hardavgtime == .
	
	collapse (sum) block`block'easyavgtime block`block'hardavgtime, by(prolific_id)
	save `"$preppeddata/Experiment 3/wtp_exp3_avgtimes_block`block'.dta"', replace
	
	restore 
}

egen avg_tasktime = mean(q_time), by(prolific_id)
gen middle80taskpct = .
gen bottom90taskpct = .

sum avg_tasktime if treatment == 1, detail
if treatment == 1 replace middle80taskpct = (avg_tasktime > r(p10) & avg_tasktime < r(p90))

sum avg_tasktime if treatment == 2, detail
if treatment == 2 replace middle80taskpct = (avg_tasktime > r(p10) & avg_tasktime < r(p90))

sum avg_tasktime if treatment == 1, detail
if treatment == 1 replace bottom90taskpct = avg_tasktime < r(p90)

sum avg_tasktime if treatment == 2, detail
if treatment == 2 replace bottom90taskpct = avg_tasktime < r(p90)

drop avg_tasktime

save `"$preppeddata/Experiment 3/wtp_intermediate_task_exp3_`source'.dta"', replace

preserve
keep prolific_id middle80taskpct bottom90taskpct
duplicates drop prolific_id, force
save `"$preppeddata/Experiment 3/middle80taskpct_`source'.dta"', replace
restore


** WTP data
use `"$preppeddata/Experiment 3/wtp_intermediate_pooled_exp3_`source'.dta"', clear

** Only keep people who are not in the ever_extreme group
merge m:1 prolific_id using `"$preppeddata/Experiment 3/ever_extreme_indicator.dta"'
keep if ever_extreme == 0 
drop _merge

** Keep relevant variables — xnorm variables are about choices 
keep prolific_id xnorm_?payment xnorm_?choicefinal ///
 treatment feedback block1pctdiff block2pctdiff bottom90fullpct ///
  durationinseconds block1pctcorrecteasy block1pctcorrecthard ///
  block2pctcorrecteasy block2pctcorrecthard

destring xnorm_?payment, replace

** Reshape from wide to long
reshape long xnorm_@payment xnorm_@choicefinal, ///
 i(prolific_id) j(counter)
 
drop if counter == 0

** Convert to numeric
destring treatment, replace
destring feedback, replace

** Rename for clarity
rename xnorm_choicefinal choice
rename xnorm_payment payment

gen block = 1 if counter == 1 | counter == 2 | counter == 3
replace block = 2 if counter == 4 | counter == 5 | counter == 6

** Create choicenum
destring choice, gen(choicenum) i("left" "right")

** Convert choices to terms of left
replace choicenum = choicenum - 1 if strpos(choice, "right")

** Convert string choice
replace choice = string(choicenum) + "left"

** Add number of times 1 left was chosen
gen strategy_1left = (choice == "1left")
egen times_1left = total(strategy_1left), by(prolific_id)
drop strategy_1left

** Add increments & max bonus of MPL by incentive
gen increment = 0.25
gen max_bonus = 4

** Calculate WTP (WTP is equated with the midpoint of the crossover interval.) 
gen WTP = ((max_bonus - (choicenum -1) * increment) + ///
(max_bonus - (choicenum *increment))) / 2 if choicenum >= 17

replace WTP = -((max_bonus - (32 - choicenum) * increment) ///
+ (max_bonus - (33 - choicenum) * increment)) / 2 if choicenum < 17

** Merge in the middle 80 pct task indicator
merge m:1 prolific_id using `"$preppeddata/Experiment 3/middle80taskpct_`source'.dta"'
drop _merge

drop increment max_bonus counter
save `"$preppeddata/Experiment 3/wtp_exp3_`source'.dta"', replace

preserve
** Construct one more data set: three rows for each individual for each incentive level
** and WTP for block1 and block 2

keep WTP payment prolific_id feedback block block1pctdiff block2pctdiff ///
middle80taskpct bottom90fullpct block1pctcorrecteasy block1pctcorrecthard ///
block2pctcorrecteasy block2pctcorrecthard

destring feedback, replace

** Reshape data
reshape wide WTP, i(prolific_id payment) j(block)

** Save data
save `"$preppeddata/Experiment 3/wtp_incentiveblock_exp3_`source'.dta"', replace

restore

run "$do/Experiment 3/Build/Exp3WTPAllSubjectsBuild.do"
