/******************************************************************************

Exp3WTPAllSubjectsBuild.do

This file prepares ETP data for all subjects who successfully completed
Exp 3. This is a separate file because the main build file excludes 
participants were censored at $2 or $4.

*******************************************************************************/
** Import data
use `"$preppeddata/Experiment 3/wtp_allparticipants.dta"', clear

** Keep relevant variables — xnorm variables are about choices 
keep prolific_id xnorm_?payment xnorm_?choicefinal 

destring xnorm_?payment, replace

** Reshape from wide to long
reshape long xnorm_@payment xnorm_@choicefinal, ///
 i(prolific_id) j(counter)
 
drop if counter == 0

** Rename for clarity
rename xnorm_choicefinal choice
rename xnorm_payment payment

** Create choicenum
destring choice, gen(choicenum) i("left" "right")

** Convert choices to terms of left
replace choicenum = choicenum - 1 if strpos(choice, "right")

** Convert string choice
replace choice = string(choicenum) + "left"

** Add number of times 1 left was chosen
gen strategy_1left = (choice == "1left")
egen times_1left = total(strategy_1left), by(prolific_id)
drop strategy_1left

** Add increments & max bonus of MPL by incentive
gen increment = 0.25
gen max_bonus = 4

** Calculate WTP (WTP is equated with the midpoint of the crossover interval.) 
gen WTP = ((max_bonus - (choicenum -1) * increment) + ///
(max_bonus - (choicenum *increment))) / 2 if choicenum >= 17

replace WTP = -((max_bonus - (32 - choicenum) * increment) ///
+ (max_bonus - (33 - choicenum) * increment)) / 2 if choicenum < 17

** Get % of responses bottom-censored or top-censored
count
local num_responses `r(N)'

** Top censored
count if WTP == 4.125
local num_top `r(N)'

local top_censored: di %3.2f (num_top / num_responses) * 100

** Bottom censored
count if WTP == -4.125
local num_bottom `r(N)'

local bottom_censored: di %3.2f (num_bottom / num_responses) * 100

latex_write \expthreetopcensored "`top_censored'"
latex_write \expthreebottomcensored "`bottom_censored'"
