/******************************************************************************

Exp3FinalRegAnalysis.do

This file runs regressions on the data from Experiment 3.

*******************************************************************************/

** Import data
use `"$preppeddata/Experiment 3/wtp_intermediate_task_exp3_launch.dta"', clear

** Add number of participant counts — divide by 14 since this is the
** task data
count
local full_particpants = r(N) / 14
display `full_particpants'
		
count if treatment == 1 
local t1_participants = r(N) / 14
display `t1_participants'	
	
count if treatment == 2
local t2_participants = r(N) /14
display `t2_participants'	

count if block1pctdiff <= 0 & treatment == 1 
local negzeropctdiff = r(N) / 14
display `negzeropctdiff'	

count if block1pctdiff > 0 & treatment == 1 
local nonzeropctdiff = r(N) / 14
display `nonzeropctdiff'	

** For the first regression, we should exclude cases where the WTP
** influenced the 7th task
drop if q_computerselect == 0

** Destring feedback
destring feedback, replace

** Gen block2 marker
gen block2 = (block == 2)

** Gen treatment marker
gen lengthtreatment = (treatment == 1)

** Include labels for exporting
label variable easy_discern "More Discernible"
label variable easy_length "Shorter"
label variable payment "Incentive (\\$)"
label variable feedback "Feedback"
label variable block2 "Block 2"
label variable lengthtreatment "Length Treatment"

** A regression of getting answers correct on length + discernibility, by block
foreach block in 1 2 {

	** Define locals for different groups — marker for tex files,
	**  — and keep observations based on the pilot specified 
		
	if `block' == 1 {
		local marker "b1" 
		local blockspec "1"
		local condition "if block == 1"
	}
	else if `block' == 2 {
		local marker "b2"
		local blockspec "2"
		local condition "if block == 2"
	} 
		

	** A regression of getting answers correct on length + discernibility
	foreach regtype in "reg" "reg_nocluster" "incentive" "incent_tasktype" {
		if "`regtype'" == "reg" { 
			local covariates "lengthtreatment"
			local options "vce(cluster prolific_id)" 
		}
		else if "`regtype'" == "reg_nocluster" { 
			local covariates "lengthtreatment"
			local options ""
		}
		else if "`regtype'" == "incentive" {
			local covariates "c.payment"
			local options "vce(cluster prolific_id)"
		}

		reg q_correct easy_discern easy_length `covariates' `condition', ///
			`options' baselevels
			eststo `regtype'_correct_`marker'
			estadd local n_participants `full_particpants'
			estadd local blockspec "`blockspec'"
		}
		
	}

** Create table for effect of length/discernibility on accuracy, block 1 & 2
esttab reg_correct_b1 incentive_correct_b1 ///
	reg_correct_b2 incentive_correct_b2  ///
	using `"$tables/Experiment 3/answers_correct_reg_block1and2.tex"', ///
	replace se nonote numbers b(%8.2f) se(%8.3f) noomit nobaselevels ///
	mgroups("Answered Task Correctly", pattern(1 0 0 0 0) ///
	prefix(\multicolumn{@span}{c}{) suffix(}) span) nomtitles ///
	star(* 0.10 ** 0.05 *** 0.01) ///
	label interaction(" $\times $ ") ///
	stats(N n_participants blockspec, ///
	l("Observations" "Number of Participants" "Block") ///
	fmt(%8.0fc %8.2fc %8.0fc))

** Get differences on coefficients of length and discernibility between block 1 and 2
suest reg_nocluster_correct_b1 reg_nocluster_correct_b2, vce(cluster prolific_id)

** Length and discernibility in block 1
lincom [reg_nocluster_correct_b1_mean]easy_discern - [reg_nocluster_correct_b1_mean]easy_length	
local ldblockonecoeffdiff: di %8.3f `r(estimate)'
local ldblockonecoeffdiffpct: di %3.1f `r(estimate)' * 100
local ldblockonecoeffdiffse: di %8.3f `r(se)'
				
test [reg_nocluster_correct_b1_mean]easy_discern = [reg_nocluster_correct_b1_mean]easy_length
local ldblockonecoeffdiffpvalue: di %3.2f `r(p)'

** Length and discernibility in block 2
lincom [reg_nocluster_correct_b2_mean]easy_discern - [reg_nocluster_correct_b2_mean]easy_length	
local ldblocktwocoeffdiff: di %8.3f `r(estimate)'
local ldblocktwocoeffdiffpct: di %3.1f `r(estimate)' * 100
local ldblocktwocoeffdiffse: di %8.3f `r(se)'
				
test [reg_nocluster_correct_b2_mean]easy_discern = [reg_nocluster_correct_b2_mean]easy_length
local ldblocktwocoeffdiffpvalue: di %3.2f `r(p)'

** Length between block 1 and 2
lincom [reg_nocluster_correct_b1_mean]easy_length - [reg_nocluster_correct_b2_mean]easy_length	
local length_coef_diff: di %8.3f `r(estimate)'
local length_coef_diff_se: di %8.3f `r(se)'
				
test [reg_nocluster_correct_b1_mean]easy_length = [reg_nocluster_correct_b2_mean]easy_length
local length_coeff_pvalue: di %8.3f `r(p)'
				
** Discernibility between block 1 and 2
lincom [reg_nocluster_correct_b1_mean]easy_discern - [reg_nocluster_correct_b2_mean]easy_discern	
local discern_coef_diff: di %8.3f `r(estimate)'
local discern_coef_diff_se: di %8.3f `r(se)'
				
test [reg_nocluster_correct_b1_mean]easy_discern = [reg_nocluster_correct_b2_mean]easy_discern
local discern_coeff_pvalue: di %8.3f `r(p)'

** Write to latex commands
latex_write \lengthcoeffdiff "`length_coef_diff'"
latex_write \lengthcoeffdiffse "`length_coef_diff_se'"
latex_write \lengthcoeffdiffpvalue "`length_coeff_pvalue'"
latex_write \discerncoeffdiff "`discern_coef_diff'"
latex_write \discerncoeffdiffse "`discern_coef_diff_se'"
latex_write \discerncoeffdiffpvalue "`discern_coeff_pvalue'"

latex_write \ldblockonecoeffdiff "`ldblockonecoeffdiff'"
latex_write \ldblockonecoeffdiffpct "`ldblockonecoeffdiffpct'"
latex_write \ldblockonecoeffdiffse "`ldblockonecoeffdiffse'"
latex_write \ldblockonecoeffdiffpvalue "`ldblockonecoeffdiffpvalue'"
latex_write \ldblocktwocoeffdiff "`ldblockonecoeffdiff'"
latex_write \ldblocktwocoeffdiffpct "`ldblocktwocoeffdiffpct'"
latex_write \ldblocktwocoeffdiffse "`ldblockonecoeffdiffse'"
latex_write \ldblocktwocoeffdiffpvalue "`ldblocktwocoeffdiffpvalue'"

** Import data
use `"$preppeddata/Experiment 3/wtp_intermediate_task_exp3_launch.dta"', clear

** Destring feedback
destring feedback, replace

** Gen block2 marker
gen block2 = (block == 2)

** Gen treatment marker
gen lengthtreatment = (treatment == 1)

** Include labels for exporting
label variable easy_discern "More Discernible"
label variable easy_length "Shorter"
label variable payment "Incentive (\\$)"
label variable feedback "Feedback"
label variable block2 "Block 2"
label variable lengthtreatment "Length Treatment"

** Gen indicator for block1pctdiff<=0
gen b1pctdiffleqzero = (block1pctdiff<=0)

** Keep relevant variables				
keep prolific_id block1pctdiff block2pctdiff feedback b1pctdiffleqzero treatment

** Drop duplicates so we have one row per participant
duplicates drop

** Reshape 
reshape long block@pctdiff, i(prolific_id) j(block)

** Destring feedback
destring feedback, replace
gen block2 = (block == 2)

** Add labels
label variable feedback "Feedback"
label variable block2 "Block 2"

** A regression of getting answers correct on block + feedback, pooled

foreach regtype in  "block_feedback_reg_t1" "block_feedback_reg_t2" ///
	"block_negzeropct" "block_nonzeropct" ///
	"block_negzeropct_nc" "block_nonzeropct_nc" ///
	"block_feedback_negzeropct" "block_feedback_nonzeropct" {
		
	if "`regtype'" == "block_feedback_reg_t1" { 
		local covariates "c.feedback c.block2#c.feedback" 
		local condition "if treatment == 1"
		local num_participants `t1_participants'
		local accuracy_diff "All"
		local treatmentarm "Length"
		local options "vce(cluster prolific_id)"
	}
	else if "`regtype'" == "block_feedback_reg_t2" { 
		local covariates "c.feedback c.block2#c.feedback" 
		local condition "if treatment == 2"
		local num_participants `t2_participants'
		local accuracy_diff "All"
		local treatmentarm "Discernibility"
		local options "vce(cluster prolific_id)"
	}
	else if "`regtype'" == "block_negzeropct" { 
		local covariates "" 
		local condition "if b1pctdiffleqzero == 1 & treatment == 1"
		local num_participants `negzeropctdiff'
		local accuracy_diff "\(\leq 0\)"
		local treatmentarm "Length"
		local options "vce(cluster prolific_id)"
	}
	else if "`regtype'" == "block_nonzeropct" { 
		local covariates "" 
		local condition "if b1pctdiffleqzero == 0 & treatment == 1"
		local num_participants `nonzeropctdiff'
		local accuracy_diff "\(> 0\)"
		local treatmentarm "Length"
		local options "vce(cluster prolific_id)"
	}
	else if "`regtype'" == "block_negzeropct_nc" { 
		local covariates "" 
		local condition "if b1pctdiffleqzero == 1 & treatment == 1"
		local num_participants `negzeropctdiff'
		local accuracy_diff "\(\leq 0\)"
		local treatmentarm "Length"
		local options ""
	}
	else if "`regtype'" == "block_nonzeropct_nc" { 
		local covariates "" 
		local condition "if b1pctdiffleqzero == 0  & treatment == 1"
		local num_participants `nonzeropctdiff'
		local accuracy_diff "\(> 0\)"
		local treatmentarm "Length"
		local options ""
	}
	else if "`regtype'" == "block_feedback_negzeropct" { 
		local covariates "c.feedback c.block2#c.feedback" 
		local condition "if b1pctdiffleqzero == 1  & treatment == 1"
		local num_participants `negzeropctdiff'
		local accuracy_diff "\(\leq 0\)"
		local treatmentarm "Length"
		local options "vce(cluster prolific_id)"
	}
	else if "`regtype'" == "block_feedback_nonzeropct" { 
		local covariates "c.feedback c.block2#c.feedback" 
		local condition "if b1pctdiffleqzero == 0  & treatment == 1"
		local num_participants `nonzeropctdiff'
		local accuracy_diff "\(> 0\)"
		local treatmentarm "Length"
		local options "vce(cluster prolific_id)"
	}
		reg blockpctdiff c.block2 `covariates' `condition', ///
			`options' baselevels
			eststo `regtype'
			estadd local n_participants `num_participants'
			estadd local pct_diff `accuracy_diff'
			estadd local treatment "`treatmentarm'"
	}

// Calculate sum of block 2 & cons for columns 3 and 4
suest block_nonzeropct_nc block_negzeropct_nc, vce(cluster prolific_id)

// Col 3 sum
lincom [block_negzeropct_nc_mean]c.block2 + ///
	[block_negzeropct_nc_mean]_cons
				
local negzerocolsum: di %8.2f `r(estimate)'
local negzerocolsumse: di %8.3f `r(se)'

// Col 4 sum
lincom [block_nonzeropct_nc_mean]c.block2 + ///
	[block_nonzeropct_nc_mean]_cons
				
local greaterthanzerosum: di %8.2f `r(estimate)'
local greaterthanzerosumse: di %8.3f `r(se)'
				
// Difference between sums in col 3 and 4
lincom ([block_negzeropct_nc_mean]c.block2 + ///
	[block_negzeropct_nc_mean]_cons)  - ///
	([block_nonzeropct_nc_mean]c.block2 + ///
	[block_nonzeropct_nc_mean]_cons)
				
local accdiffsumdiff: di %8.3f `r(estimate)'
local accdiffsumdiffse: di %8.3f `r(se)'
				
test ([block_negzeropct_nc_mean]c.block2 + ///
	[block_negzeropct_nc_mean]_cons)  = ///
	([block_nonzeropct_nc_mean]c.block2 + ///
	[block_nonzeropct_nc_mean]_cons)
local accdiffsumdiffpvalue: di %8.3f `r(p)'

// Write to Latex
latex_write \negzerocolsum "`negzerocolsum'"
latex_write \negzerocolsumse "`negzerocolsumse'"
latex_write \greaterthanzerosum "`greaterthanzerosum'"
latex_write \greaterthanzerosumse "`greaterthanzerosumse'"
latex_write \accdiffsumdiff "`accdiffsumdiff'"
latex_write \accdiffsumdiffse "`accdiffsumdiffse'"
latex_write \accdiffsumdiffpvalue "`accdiffsumdiffpvalue'"

** Create table for effect of dummy and feedback on accuracy, pooled
esttab block_feedback_reg_t1 block_feedback_reg_t2 ///
	block_negzeropct block_nonzeropct ///
	block_feedback_negzeropct block_feedback_nonzeropct ///
	using `"$tables/Experiment 3/correct_feedback_block.tex"', ///
	replace se booktabs nonote numbers b(%8.2f) se(%8.3f) noomit nobaselevels ///
	mgroups("Accuracy Difference Between Easy and Hard Tasks", pattern(1 0 0 0 0 0) ///
	prefix(\multicolumn{@span}{c}{) suffix(}) span) nomtitles ///
	star(* 0.10 ** 0.05 *** 0.01) ///
	label interaction(" $\times $ ") ///
	stats(N n_participants pct_diff treatment, ///
	l("Observations" "Number of Participants" "Participant B1 Acc. Diff." "Treatment Arm") ///
	fmt(%8.0fc %8.2fc %8.0fc))


** Now, regression on time taken in task (avg diff. between hard and easy)

** Merge in block times
foreach block in 1 2 {
	merge m:1 prolific_id using ///
		`"$preppeddata/Experiment 3/wtp_exp3_avgtimes_block`block'"'
	drop _merge 
}

** Take difference
gen block1timediff = block1hardavgtime - block1easyavgtime
gen block2timediff = block2hardavgtime - block2easyavgtime

** Only keep people in treatment 1
keep if treatment == 1 

** Keep relevant variables
keep block1timediff block2timediff b1pctdiffleqzero feedback prolific_id

** Drop duplicates so we have one row per participant
duplicates drop

** Reshape 
reshape long block@timediff, i(prolific_id) j(block)

** Gen block 2 marker
gen block2 = (block == 2)

** Add labels
label variable block2 "Block 2"
label variable b1pctdiffleqzero "B1 Acc. Diff \(\leq 0\)"

foreach i in 0 180 300 { // 1 represents no windosrizing
	preserve
	if `i' != 0 {
		replace blocktimediff = `i' if blocktimediff > `i'
		local winsorizespec `"\(T=`i'\)"'
	}
	if `i' == 0 local winsorizespec "No"
	
	reg blocktimediff c.block2##c.b1pctdiffleqzero, ///
		vce(cluster prolific_id) 
	eststo base_`i'
	estadd local n_participants `t1_participants'
	estadd local winsorizeinfo `winsorizespec'
	
	reg blocktimediff c.block2##c.b1pctdiffleqzero##c.feedback, ///
		vce(cluster prolific_id) 
	eststo base_interact_`i'
	estadd local n_participants `t1_participants'
	estadd local winsorizeinfo `winsorizespec'
	restore
}
	
** Create table for effect of block, feedback, acc diff 
esttab base_0 base_interact_0 base_300 ///
	base_interact_300 base_180 base_interact_180 ///
	using `"$tables/Experiment 3/decision_time_reg.tex"', ///
	replace se booktabs nonote numbers b(%8.2f) se(%8.3f) noomit nobaselevels ///
	mgroups("Average Difference in Time Spent on Hard vs. Easy Tasks, By Block", pattern(1 0 0 0 0 0) ///
	prefix(\multicolumn{@span}{c}{) suffix(}) span) nomtitles ///
	star(* 0.10 ** 0.05 *** 0.01) ///
	label interaction(" $\times $ ") ///
	stats(N n_participants winsorizeinfo, ///
	l("Observations" "Number of Participants" "Winsorized at \(T\) Seconds") ///
	fmt(%8.0fc %8.2fc %8.0fc))	

** Import data
use `"$preppeddata/Experiment 3/wtp_exp3_launch.dta"', clear

** Get increase in WTP for extra $1 for each treatment, block 1
reg WTP payment if treatment == 1 & block == 1, vce(cluster prolific_id)
local treatoneblockonewtp: di %3.2f _b[payment]
local treatoneblockonewtpse: di %9.3f _se[payment]
latex_write \treatoneblockonewtp "`treatoneblockonewtp'"
latex_write \treatoneblockonewtpse "`treatoneblockonewtpse'"

reg WTP payment if treatment == 2 & block == 1, vce(cluster prolific_id)
local treattwoblockonewtp: di %3.2f _b[payment]
local treattwoblockonewtpse: di %9.3f _se[payment]
latex_write \treattwoblockonewtp "`treattwoblockonewtp'"
latex_write \treattwoblockonewtpse "`treattwoblockonewtpse'"

** Get increase in WTP for extra $1 for each treatment, block 2
reg WTP payment if treatment == 1 & block == 2, vce(cluster prolific_id)
local treatoneblocktwowtp: di %3.2f _b[payment]
local treatoneblocktwowtpse: di %9.3f _se[payment]
latex_write \treatoneblocktwowtp "`treatoneblocktwowtp'"
latex_write \treatoneblocktwowtpse "`treatoneblocktwowtpse'"

reg WTP payment if treatment == 2 & block == 2, vce(cluster prolific_id)
local treattwoblocktwowtp: di %3.2f _b[payment]
local treattwoblocktwowtpse: di %9.3f _se[payment]
latex_write \treattwoblocktwowtp "`treattwoblocktwowtp'"
latex_write \treattwoblocktwowtpse "`treattwoblocktwowtpse'"

** Get difference in block 1 and 2 for treatment 1
reg WTP payment if treatment == 1 & block == 1
eststo treatoneblockone

reg WTP payment if treatment == 1 & block == 2
eststo treatoneblocktwo

suest treatoneblockone treatoneblocktwo, vce(cluster prolific_id)
lincom [treatoneblockone_mean]payment - [treatoneblocktwo_mean]payment				
local treatoneblockdiffwtp: di %8.2f `r(estimate)'
			
test [treatoneblockone_mean]payment = [treatoneblocktwo_mean]payment
local treatoneblockdiffwtppvalue: di %8.2f `r(p)'

latex_write \treatoneblockdiffwtp "`treatoneblockdiffwtp'"
latex_write \treatoneblockdiffwtppvalue "`treatoneblockdiffwtppvalue'"
			
** Regression of incentive on WTP
** Gen block2 marker
gen block2 = (block == 2)

** Label variable for exporting
label variable payment "Incentive (\\$)"
label variable block2 "Block 2"
label variable block1pctdiff "B1 Acc. Diff."
label variable block2pctdiff "B2 Acc. Diff."
label variable feedback "Feedback"

** Add labels to treatment arms
label define treatment_lbl 1 "Length" 2 "Discernibility"
label values treatment treatment_lbl

foreach regspec in "reg" "tobit" {
	preserve
	if "`regspec'" == "reg" {
		local censors ""
	}
	if "`regspec'" == "tobit" {
		local censors "ll(-4) ul(4)"
	}

	foreach group in "all" "drop10pct" {
		if "`group'" == "drop10pct" {
			keep if bottom90taskpct == 1 
		}
		
		count
		local full_particpants = r(N) / 6
			
		count if treatment == 1 
		local t1_participants = r(N) / 6
			
		count if treatment == 2
		local t2_participants = r(N) / 6

		count if block1pctdiff <= 0 & treatment == 1
		local negzeropctdiff = r(N) / 6

		count if block1pctdiff > 0 & treatment == 1
		local nonzeropctdiff = r(N) / 6
		
		** A regression of incentive on WTP
		foreach regtype in "reg_treat1" "reg_treat2" ///
		"reg_treat1_nocluster" "reg_treat2_nocluster" ///
		"reg_treat1_feedback" "reg_treat2_feedback" ///
		"reg_treat1_feedback_nc" "reg_treat2_feedback_nc" ///
		"reg_treat1_pctdiff" "reg_treat2_pctdiff" {
			
			if "`regtype'" == "reg_treat1" { 
				local covariates "" 
				local condition "if treatment == 1"
				local num_participants `t1_participants'
				local accuracy_diff "All"
				local treatmentarm "Length"
				local options "vce(cluster prolific_id)"
			}
			else if "`regtype'" == "reg_treat2" { 
				local covariates "" 
				local condition "if treatment == 2"
				local num_participants `t2_participants'
				local accuracy_diff "All"
				local treatmentarm "Discernibility"
				local options "vce(cluster prolific_id)"
			}
			if "`regtype'" == "reg_treat1_nocluster" { 
				local covariates "" 
				local condition "if treatment == 1"
				local num_participants `t1_participants'
				local accuracy_diff "All"
				local treatmentarm "Length"
				local options ""
			}
			else if "`regtype'" == "reg_treat2_nocluster" { 
				local covariates "" 
				local condition "if treatment == 2"
				local num_participants `t2_participants'
				local accuracy_diff "All"
				local treatmentarm "Discernibility"
				local options ""
			}
			else if "`regtype'" == "reg_treat1_feedback" { 
				local covariates "c.payment#c.feedback c.block2#c.feedback c.payment#c.block2#c.feedback c.feedback" 
				local condition "if treatment == 1"
				local num_participants `t1_participants'
				local accuracy_diff "All"
				local treatmentarm "Length"
				local options "vce(cluster prolific_id)"
			}
			else if "`regtype'" == "reg_treat2_feedback" { 
				local covariates "c.payment#c.feedback c.block2#c.feedback c.payment#c.block2#c.feedback c.feedback" 
				local condition "if treatment == 2"
				local num_participants `t2_participants'
				local accuracy_diff "All"
				local treatmentarm "Discernibility"
				local options "vce(cluster prolific_id)"
			}
			else if "`regtype'" == "reg_treat1_feedback_nc" { 
				local covariates "c.payment#c.feedback c.block2#c.feedback c.payment#c.block2#c.feedback c.feedback" 
				local condition "if treatment == 1"
				local num_participants `t1_participants'
				local accuracy_diff "All"
				local treatmentarm "Length"
				local options ""
			}
			else if "`regtype'" == "reg_treat2_feedback_nc" { 
				local covariates "c.payment#c.feedback c.block2#c.feedback c.payment#c.block2#c.feedback c.feedback" 
				local condition "if treatment == 2"
				local num_participants `t2_participants'
				local accuracy_diff "All"
				local treatmentarm "Discernibility"
				local options ""
			}
			else if "`regtype'" == "reg_treat1_pctdiff" { 
				local covariates "c.payment#c.feedback c.block2#c.feedback c.payment#c.block2#c.feedback c.feedback" 
				local condition "if block1pctdiff <= 0 & treatment == 1"
				local num_participants `negzeropctdiff'
				local accuracy_diff "\(\leq 0\)"
				local treatmentarm "Length"
				local options "vce(cluster prolific_id)"
			}
			else if "`regtype'" == "reg_treat2_pctdiff" { 
				local covariates "c.payment#c.feedback c.block2#c.feedback c.payment#c.block2#c.feedback c.feedback" 
				local condition "if block1pctdiff > 0 & treatment == 1"
				local num_participants `nonzeropctdiff'
				local accuracy_diff "\(> 0\)"
				local treatmentarm "Length"
				local options "vce(cluster prolific_id)"
			}

						
			`regspec' WTP c.payment c.payment#c.block2 c.block2 `covariates' `condition', ///
				`censors' baselevels `options'
				eststo `regtype'
				estadd local n_participants `num_participants'
				estadd local pct_diff `accuracy_diff'
				estadd local treatment "`treatmentarm'"
				
			** Write some coefficients and SEs to Latex
			if "`regtype'" == "reg_treat1_feedback" & "`group'" == "all" ///
				& "`regspec'" == "reg" {
				local controlblocktwoincrease: di %3.2f _b[c.payment#c.block2]
				local controlblocktwoincreasese: di %9.3f _se[c.payment#c.block2]
				latex_write \controlblocktwoincrease "`controlblocktwoincrease'"
				latex_write \controlblocktwoincreasese "`controlblocktwoincreasese'"
				
				local feedbackblocktwoincrease: di %3.2f _b[c.payment#c.block2#c.feedback]
				local feedbackblocktwoincreasese: di %9.3f _se[c.payment#c.block2#c.feedback]
				latex_write \feedbackblocktwoincrease "`feedbackblocktwoincrease'"
				latex_write \feedbackblocktwoincreasese "`feedbackblocktwoincreasese'"
				
				test _b[c.payment#c.block2#c.feedback] = 0
				local feedbackblocktwoincreasepvalue: di %9.3f r(p)
				latex_write \feedbackblocktwoincreasepvalue "`feedbackblocktwoincreasepvalue'"
				display `feedbackblocktwoincreasepvalue'
			}
			
			}
			
			** Get differences between coefficients
			if "`regspec'" == "reg" & "`group'" == "all" {
				suest reg_treat1_nocluster reg_treat2_nocluster, vce(cluster prolific_id)
				lincom [reg_treat1_nocluster_mean]payment - [reg_treat2_nocluster_mean]payment
				
				local incent_coef_diff: di %8.2f `r(estimate)'
				local incent_coef_diff_se: di %8.3f `r(se)'
				
				test [reg_treat1_nocluster_mean]payment = [reg_treat2_nocluster_mean]payment
				local incent_coeff_pvalue: di %8.2f `r(p)'
				
				lincom ([reg_treat1_nocluster_mean]payment + ///
				[reg_treat1_nocluster_mean]c.block2#c.payment)  - ///
				([reg_treat2_nocluster_mean]payment + ///
				[reg_treat2_nocluster_mean]c.block2#c.payment)
				
				local incent_block_coef_diff: di %8.3f `r(estimate)'
				local incent_block_coef_diff_se: di %8.3f `r(se)'
				
				test [reg_treat1_nocluster_mean]payment + ///
				[reg_treat1_nocluster_mean]c.block2#c.payment  ///
				= [reg_treat2_nocluster_mean]payment + ///
				[reg_treat2_nocluster_mean]c.block2#c.payment
				local incent_block_coeff_pvalue: di %8.3f `r(p)'
				
				// Calculate sums and save as well
				lincom [reg_treat1_nocluster_mean]payment + ///
				[reg_treat1_nocluster_mean]c.block2#c.payment
				
				local col1incentblocksum: di %8.2f `r(estimate)'
				local col1incentblocksumse: di %8.3f `r(se)'
				
				test [reg_treat1_nocluster_mean]payment = -[reg_treat1_nocluster_mean]c.block2#c.payment
				local col1incentblocksumsepvalue: di %8.3f `r(p)'
				
				lincom [reg_treat2_nocluster_mean]payment + ///
				[reg_treat2_nocluster_mean]c.block2#c.payment
				
				local col2incentblocksum: di %8.2f `r(estimate)'
				local col2incentblocksumse: di %8.3f `r(se)'
				
				test [reg_treat2_nocluster_mean]payment = -[reg_treat2_nocluster_mean]c.block2#c.payment
				local col2incentblocksumsepvalue: di %8.3f `r(p)'
				
				// Interaction of incentive and block 2 in columns 1 and 2
				lincom [reg_treat1_nocluster_mean]c.payment#c.block2 ///
					- [reg_treat2_nocluster_mean]c.payment#c.block2
				
				local incentblocktwocoeffdiff: di %8.2f `r(estimate)'
				local incentblocktwocoeffdiffse: di %8.3f `r(se)'
				
				test [reg_treat1_nocluster_mean]c.payment#c.block2 ///
					= [reg_treat2_nocluster_mean]c.payment#c.block2
				local incentblocktwocoeffdiffpvalue: di %8.2f `r(p)'
				
				// Interaction of incentive x block 2 x feedback in columns 3 and 4
				suest reg_treat1_feedback_nc reg_treat2_feedback_nc, vce(cluster prolific_id)
				
				lincom [reg_treat1_feedback_nc_mean]c.payment#c.block2#c.feedback ///
					- [reg_treat2_feedback_nc_mean]c.payment#c.block2#c.feedback
				
				local incentblockfeedbackdiff: di %8.3f `r(estimate)'
				local incentblockfeedbackdiffse: di %8.3f `r(se)'
				
				test [reg_treat1_feedback_nc_mean]c.payment#c.block2#c.feedback ///
					= [reg_treat2_feedback_nc_mean]c.payment#c.block2#c.feedback
				local incentblockfeedbackdiffpvalue: di %8.2f `r(p)'
				
				latex_write \incentcoeffdiff "`incent_coef_diff'"
				latex_write \incentcoeffdiffse "`incent_coef_diff_se'"
				latex_write \incentcoeffdiffpvalue "`incent_coeff_pvalue'"
				latex_write \incentblockcoeffdiff "`incent_block_coef_diff'"
				latex_write \incentblockcoeffdiffse "`incent_block_coef_diff_se'"
				latex_write \incentblockcoeffdiffpvalue "`incent_block_coeff_pvalue'"
				latex_write \coloneincentblocksum "`col1incentblocksum'"
				latex_write \coltwoincentblocksum "`col2incentblocksum'"
				latex_write \coloneincentblocksumse "`col1incentblocksumse'"
				latex_write \coltwoincentblocksumse "`col2incentblocksumse'"
				latex_write \coloneincentblocksumpvalue "`col1incentblocksumpvalue'"
				latex_write \coltwoincentblocksumsepvalue "`col2incentblocksumpvalue'"
				latex_write \incentblocktwocoeffdiff "`incentblocktwocoeffdiff'"
				latex_write \incentblocktwocoeffdiffse "`incentblocktwocoeffdiffse'"
				latex_write \incentblocktwocoeffdiffpvalue "`incentblocktwocoeffdiffpvalue'"
				latex_write \incentblockfeedbackdiff "`incentblockfeedbackdiff'"
				latex_write \incentblockfeedbackdiffse "`incentblockfeedbackdiffse'"
				latex_write \incentblockfeedbackdiffpvalue "`incentblockfeedbackdiffpvalue'"
				
			}


			if "`regspec'" == "reg" {
			** Create table for effect of incentive on WTP, pooled
			esttab reg_treat1 reg_treat2 ///
				reg_treat1_feedback reg_treat2_feedback ///
				reg_treat1_pctdiff reg_treat2_pctdiff ///
				using `"$tables/Experiment 3/`group'_incentive_WTP_`regspec'_pooled.tex"', ///
				order(payment c.payment#c.block2 c.payment#c.feedback ///
				c.payment#c.block2#c.feedback) ///
				replace se booktabs nonote numbers b(%8.2f) se(%8.3f) noomit nobaselevels ///
				mgroups("Willingness to Pay (\\$)", pattern(1 0 0 0 0 0) ///
				prefix(\multicolumn{@span}{c}{) suffix(}) span) nomtitles ///
				star(* 0.10 ** 0.05 *** 0.01) ///
				label interaction(" $\times $ ") ///
				stats(N n_participants pct_diff treatment, ///
				l("Observations" "Number of Participants" "Participant B1 Acc. Diff." "Treatment Arm") ///
				fmt(%8.0fc %8.2fc %8.0fc))
			}
			
			else if "`regspec'" == "tobit" & "`group'" != "drop10pct"{
				esttab reg_treat1 reg_treat2 ///
				reg_treat1_feedback reg_treat2_feedback ///
				reg_treat1_pctdiff reg_treat2_pctdiff ///
				using `"$tables/Experiment 3/`group'_incentive_WTP_`regspec'_pooled.tex"', ///
				order(payment c.payment#c.block2 c.payment#c.feedback ///
				c.payment#c.block2#c.feedback) ///
				replace se booktabs nonote numbers b(%8.2f) se(%8.3f) noomit nobaselevels ///
				mgroups("Willingness to Pay (\\$)", pattern(1 0 0 0 0 0) ///
				prefix(\multicolumn{@span}{c}{) suffix(}) span) nomtitles ///
				eqlabels(" " " " " " " ") unstack drop(/:) ///
				star(* 0.10 ** 0.05 *** 0.01) ///
				label interaction(" $\times $ ") ///
				stats(N n_participants pct_diff treatment, ///
				l("Observations" "Number of Participants" "Participant B1 Acc. Diff." "Treatment Arm") ///
				fmt(%8.0fc %8.2fc %8.0fc))	
			}
	}
	restore
}
