/******************************************************************************

Exp3RiskAversionCalibration.do

This file generates the numbers for Appendix E. 

*******************************************************************************/

** Experiment 3

**CARA
** Get WTP and save as a temp file
use `"$preppeddata/Experiment 3/wtp_exp3_launch.dta"', clear
keep if payment == 2
keep WTP block treatment
collapse (mean) WTP, by (block treatment)
rename WTP w

** Save data
tempfile exp3WTP
save "`exp3WTP'"

** Get task correct data, merge with WTP
use `"$preppeddata/Experiment 3/wtp_intermediate_task_exp3_launch.dta"', clear
gen easy = easy_discern + easy_length

gen pi_0 = .
gen pi_1 = .

** Store the probability that the task is answered correctly with and without BE
foreach easytype in 0 1 {
	foreach treatmenttype in 1 2 {
		foreach blocktype in 1 2 {
			local condition "treatment == `treatmenttype' & block == `blocktype' & easy == `easytype'"
			mean q_correct if `condition'
			
			if `easytype' == 0 replace pi_0 = r(table)[1,1] ///
				if treatment == `treatmenttype' & block == `blocktype'
			if `easytype' == 1 replace pi_1 = r(table)[1,1] ///
				if treatment == `treatmenttype' & block == `blocktype'
		}
	}
}

** Condense data set
keep treatment block pi_0 pi_1
duplicates drop

** Add r
gen r = 2

** Merge
merge 1:1 treatment block using `exp3WTP'
drop _merge

** Calculate effects using given alphas
local i = 0 // index, sorted by size

foreach alph in 0 0.00019 0.000325 0.0007 0.00087 0.0019 0.002 0.03 0.2 {
	gen alph_`i' = (pi_1 * exp(-`alph' * r) - pi_0 * exp(-`alph' * r)) ///
			/ (pi_0 * exp(-`alph'*(w+r)) + (1-pi_0)*exp(-`alph' * w))
	di "Alpha `i' = `alph'"
	local i = `i' + 1
}

** Write to latex
foreach i of numlist 0/8 {
	if `i' == 0 local alph "zero"
	if `i' == 1 local alph "I"
	if `i' == 2 local alph "II"
	if `i' == 3 local alph "III"
	if `i' == 4 local alph "IV"
	if `i' == 5 local alph "V"
	if `i' == 6 local alph "VI"
	if `i' == 7 local alph "VII"
	if `i' == 8 local alph "VIII"
	
	foreach treatmenttype in 1 2 {
		if `treatmenttype' == 1 local treat "Length"
		if `treatmenttype' == 2 local treat "Discern"
		
		foreach blocktype in 1 2 {
			if `blocktype' == 1 local block "One"
			if `blocktype' == 2 local block "Two"
			
			di "alpha: `i', treatment: `treat', block: `blocktype'"
			levelsof alph_`i' if treatment == `treatmenttype' & block == `blocktype', ///
				local(val)
			local val : di %3.2f  `val'
			di `val'

			latex_write \treat`treat'Block`block'Alph`alph' "`val'"
		}
	}
}

** Calculate effects using given rho and z
local i = 1 // index, sorted by size

foreach rho in 0 1.37 {
	if `rho' == 0 {
		gen rhoz_0 = (pi_1 - pi_0) 
		di "RhoZ 0 = `rho', `z'"
	}
	else {
		foreach z in 10 100 1000 100000 {
			
			gen rhoz_`i' = (pi_1 - pi_0)  ///
				/ (pi_0 * ((`z' + r) / (`z' + w + r))^`rho' + (1-pi_0) * ((`z' + r) / (`z' + w))^`rho')
			di "RhoZ `i' = `rho', `z'"
			local i = `i' + 1
		}
	}
}

** Write to latex
foreach i of numlist 0/4 {
	if `i' == 0 local rhoz "zero"
	if `i' == 1 local rhoz "I"
	if `i' == 2 local rhoz "II"
	if `i' == 3 local rhoz "III"
	if `i' == 4 local rhoz "IV"
	
	foreach treatmenttype in 1 2 {
		if `treatmenttype' == 1 local treat "Length"
		if `treatmenttype' == 2 local treat "Discern"
		
		foreach blocktype in 1 2 {
			if `blocktype' == 1 local block "One"
			if `blocktype' == 2 local block "Two"
			
			di "rhoz: `i', treatment: `treat', block: `blocktype'"
			levelsof rhoz_`i' if treatment == `treatmenttype' & block == `blocktype', ///
				local(val)
			local val : di %3.2f  `val'
			di `val'

			latex_write \treat`treat'Block`block'Rhoz`rhoz' "`val'"
		}
	}
}

** Get empirical estimates 

** Import data
use `"$preppeddata/Experiment 3/wtp_exp3_launch.dta"', clear

** Gen block2 marker
gen block2 = (block == 2)

** Run regression
foreach treatmenttype in 1 2 {
	if `treatmenttype' == 1 local treat "Length"
	if `treatmenttype' == 2 local treat "Discern"
		
	reg WTP c.payment c.payment#c.block2 c.block2 if treatment == `treatmenttype', ///
		baselevels vce(cluster prolific_id)
	local blockone : di %3.2f r(table)[1,1]
	local blocktwo : di %3.2f r(table)[1,1] + r(table)[1,2]

	latex_write \treat`treat'BlockOne "`blockone'"
	latex_write \treat`treat'BlockTwo "`blocktwo'"
}
