/******************************************************************************

Exp3SummaryAnalysis.do

This file runs summary stats from the Experiment 3 launch of 
the Pay to Plan project.

*******************************************************************************/

** 1. WTP Analysis
** 2. Task Analysis

** Add marker
local source "launch"

** Import data
use `"$preppeddata/Experiment 3/wtp_exp3_`source'.dta"', clear

** Take means of block 1 acc diff for treatment 1
mean block1pctdiff if block1pctdiff <= 0 & treatment == 1
local negzeromean : di %3.2f r(table)[1,1]
latex_write \negzeropctdiffmean "`negzeromean'"

mean block1pctdiff if block1pctdiff > 0 & treatment == 1
local nonzeromean : di %3.2f r(table)[1,1]
latex_write \greaterthanzeropctdiffmean "`nonzeromean'"
	
** Save number of participants as local — here, we have 6 obs for each person
** so we need to divide

count
local num_participants = r(N) / 6
latex_write \finalsampleexpthree "`num_participants'"

** Get mean WTP for each treatment and payment, by block and pooled

foreach block in 1 2 3 {
	preserve
	
	** Block "3" == Pooled
	if `block' == 1 {
		local marker "blockone" 
		keep if block == 1
	}
	else if `block' == 2 {
		local marker "blocktwo"
		keep if block == 2
	} 
	else if `block' == 3 {
		local marker ""
	}
	
	foreach treat of numlist 1 2 {
		foreach pay of numlist 2 3 4 {
			if `treat' == 1 local treat_written "one"
			if `treat' == 2 local treat_written "two"
			
			if `pay' == 2 local pay_written "two"
			if `pay' == 3 local pay_written "three"
			if `pay' == 4 local pay_written "four"
			
			mean WTP if treatment == `treat' & payment == `pay', vce(cluster prolific_id)
			matrix store_results = r(table)
			local mean : di %3.2f store_results[1,1]
			local sd : di %9.3f store_results[2,1]
			latex_write \treat`treat_written'pay`pay_written'`marker' "`mean'"
			latex_write \treat`treat_written'pay`pay_written'`marker'sd "`sd'"
		}
	}
	restore
}

** Count use of the 1-left strategy 
	
foreach x of numlist 1 2 3 4 5 6 {
	if `x' == 1 local x_written "once"
	if `x' == 2 local x_written "twice"
	if `x' == 3 local x_written "thrice"
	if `x' == 4 local x_written "four"
	if `x' == 5 local x_written "five"
	if `x' == 6 local x_written "six"
	
	preserve
	duplicates drop prolific_id, force
	
	count if times_1left >= `x'

	scalar oneleftatleast`x' = r(N)
	
	scalar oneleftatleast`x' = (oneleftatleast`x' / `num_participants') * 100
	local oneleftatleast`x': di %3.2f scalar(oneleftatleast`x')
	latex_write oneleftatleast`x_written' "`oneleftatleast`x''"
	
	restore
		
}

** Count censored WTP at bottom and top
foreach x of numlist 2 3 4 {
		
	if `x' == 2 local x_written "two"
	if `x' == 3 local x_written "three"
	if `x' == 4 local x_written "four"
		
	foreach i of numlist 0 33 {
		gen strategy_`i'left_`x' = (choicenum == `i' & payment == `x')
		egen times_`i'left_`x' = total(strategy_`i'left_`x'), by(prolific_id)
			
		gen always_`i'left_`x' = (times_`i'left_`x' == 2)
		drop strategy_`i'left_`x' times_`i'left_`x'
				
		if `i' == 0 { //i.e. 0 left — always want easy
			count if always_`i'left_`x' == 1
			scalar always_easy_`x_written' = r(N) / 6
			scalar pct_easy_`x' = (always_easy_`x_written' / `num_participants') * 100
			local pct_easy_`x': di %3.2f scalar(pct_easy_`x')
				
			latex_write `block_written'sharealwayseasy`x_written' "`pct_easy_`x''"
		}
				
		if `i' == 33 {
			count if always_`i'left_`x' == 1
			scalar always_hard_`x_written' = r(N) / 6
			scalar pct_hard_`x' = (always_hard_`x_written' / `num_participants') * 100
			local pct_hard_`x': di %3.2f scalar(pct_hard_`x')
				
			latex_write `block_written'sharealwayshard`x_written' "`pct_hard_`x''"
		}
	}
}

	
foreach block of numlist 1 2 {
	if `block' == 1 local block_written "\blockone"
	if `block' == 2 local block_written "\blocktwo"
	
	preserve
	
	keep if block == `block'
	
	count 
	local num_participants = r(N) / 3
	
	** Count censored WTP at bottom and top
	foreach x of numlist 2 3 4 {
		
		if `x' == 2 local x_written "two"
		if `x' == 3 local x_written "three"
		if `x' == 4 local x_written "four"
		
		count if payment == `x' & choice == "0left"
		local pct_always_easy = (r(N) /`num_participants') * 100
		local pct_always_easy: di %3.2f `pct_always_easy'
		latex_write `block_written'sharealwayseasy`x_written' "`pct_always_easy'"
		
		count if payment == `x' & choice == "33left"
		local pct_always_hard = (r(N) /`num_participants') * 100
		local pct_always_hard: di %3.2f `pct_always_hard'
		latex_write `block_written'sharealwayshard`x_written' "`pct_always_hard'"
		}
	
	restore
}

** Behavior groups within blocks — more detailed
gen dollar_change = ""

foreach block of numlist 1 2 {
	preserve
	keep if block == `block'

	** Look at within-block behavior
	bysort prolific_id (payment): gen numeric_block_change = WTP[_n] - WTP[_n-1]
	
	replace dollar_change = "Increased" if numeric_block_change > 0 
	replace dollar_change = "Decreased" if numeric_block_change < 0 
	replace dollar_change = "Same" if numeric_block_change == 0 
	
	drop if numeric_block_change == .
	drop numeric_block_change

	keep dollar_change prolific_id payment
	reshape wide dollar_change, i(prolific_id) j(payment)

	gen group_type = .

	** 1 = Constant or increasing group
	** 2 = All equal group
	** 3 = Decreasing group
	** 4 = Non-monotonic, one increasing, one decreasing 

	label define group_lbl 1 "Increasing Group" ///
		2 "All Equal" 3 "Decreasing Group" 4 "Non-monotonic Group", modify
		
	foreach i of numlist 3 4 {
		foreach j of numlist 3 4 {
			if `i' != `j' {
				replace group_type = 1 ///
					if (dollar_change`i' == "Increased" & dollar_change`j' == "Same") ///
						| (dollar_change`i' == "Increased" & dollar_change`j' == "Increased")
						
				replace group_type = 2 ///
					if dollar_change`i' == "Same" & dollar_change`j' == "Same"
					
				replace group_type = 3 ///
					if dollar_change`i' == "Decreased" & dollar_change`j' == "Same" ///
						| (dollar_change`i' == "Decreased" & dollar_change`j' == "Decreased")
				
				replace group_type = 4 /// 
					if dollar_change`i' == "Increased" & dollar_change`j' == "Decreased"
				
			}
		}
	}

	label values group_type group_lbl
	
	gen block`block'increasing = (group_type == 1)
	gen block`block'allequal = (group_type == 2)
	gen block`block'decreasing = (group_type == 3)
	gen block`block'nonmonotonic = (group_type == 4)
	
	keep prolific_id block`block'increasing ///
		block`block'allequal block`block'decreasing ///
		block`block'nonmonotonic
	
	duplicates drop prolific_id, force
	
	save `"$preppeddata/Experiment 3/wtp_exp3_grouptype_block`block'.dta"', replace
	
	restore
}		

run "$do/Experiment 3/Build/Exp3AddtlBuild.do"

*************************************************************************************
** TASK ANALYSIS **

** Add marker
local source "launch"

** Import data
use `"$preppeddata/Experiment 3/wtp_intermediate_task_exp3_`source'.dta"', clear

** Calculate time by task type
foreach pcttype of numlist 0 1 {	
		foreach equation of numlist 10 100 {
			if `pcttype' == 0 local discern "hard"
			if `pcttype' == 1 local discern "\easy"
			if `equation' == 10 local length "easy"
			if `equation' == 100 local length "hard"
			
			if !(`pcttype' == 1 & `equation' == 10) {
				mean q_time if easy_discern == `pcttype' ///
				& q_numequations == `equation', vce(cluster prolific_id)
				matrix store_results = r(table)
				local mean : di %3.0f store_results[1,1]
				local sd : di %9.3f store_results[2,1]
				latex_write `discern'discern`length'length "`mean'"
				latex_write `discern'discern`length'lengthsd "`sd'"
			}
		}
}

** Get percent correct by task type
foreach block in 1 2 3 {

	** Define locals for different groups — marker for tex files,
	**  — and keep observations based on the pilot specified 
	
	preserve
	
	** Block "3" == Pooled
	if `block' == 1 {
		local marker "blockone" 
		keep if block == 1
	}
	else if `block' == 2 {
		local marker "blocktwo"
		keep if block == 2
	} 
	else if `block' == 3 {
		local marker ""
	}
	
	foreach group in 1 2 3 4 {
		** Group 1  = $2 condition
		** Group 2 = $3 condition
		** Group 3 = $4 condition
		** Group 4 = Pooled
		
		if `group' == 1 {
			local marker2 "\twodollar"
			local condition "& payment == 2"
		}
		else if `group' == 2 {
			local marker2 "\threedollar" 
			local condition "& payment == 3"
		}
		else if `group' == 3 {
			local marker2 "\fourdollar" 
			local condition "& payment == 4"
		}
		else if `group' == 4 {
			local marker2 "pooled"
			local condition ""
		}
		
		foreach pcttype of numlist 0 1 {	
			foreach equation of numlist 10 100 {
				if `pcttype' == 0 local discern "hard"
				if `pcttype' == 1 local discern "easy"
				if `equation' == 10 local length "easy"
				if `equation' == 100 local length "hard"
			
				** No easy/easy type
				if !(`pcttype' == 1 & `equation' == 10) {
					mean q_correct if easy_discern == `pcttype' ///
					& q_numequations == `equation' `condition', ///
					vce(cluster prolific_id)
					matrix store_results = r(table)
					local mean : di %3.2f store_results[1,1]
					local sd : di %9.3f store_results[2,1]
					latex_write `marker2'`discern'd`length'l`marker' "`mean'"
					latex_write `marker2'`discern'd`length'l`marker'sd "`sd'"
				}
			}
		}
		
	}
	
	restore
}

egen tasktype = group(easy_discern easy_length)
label define task_types 1 "60% or 40% Correct, 100 Eq. (Baseline)" ///
	2 "60% or 40% Correct, 10 Eq. (Easy, Length Arm)" ///
	3 "95% or 5% Correct, 100 Eq. (Easy, Discernibility Arm)", modify
	
label values tasktype task_types
label variable q_time "Time Spent on Task in Seconds"

** Get differences in task accuracy with SEs
reg q_correct i.tasktype
local lengthtaskdiff: di %3.0f _b[2.tasktype] * 100
local lengthtaskdiffdec: di %3.2f _b[2.tasktype]
local lengthtaskdiffse: di %9.3f _se[2.tasktype] * 100
local discerntaskdiff: di %3.0f _b[3.tasktype] * 100
local discerntaskdiffdec: di %3.2f _b[3.tasktype]
local discerntaskdiffse: di %9.3f _se[3.tasktype] * 100

** Write to Latex
latex_write \lengthtaskdiff "`lengthtaskdiff'"
latex_write \lengthtaskdiffdec "`lengthtaskdiffdec'"
latex_write \lengthtaskdiffse "`lengthtaskdiffse'"
latex_write \discerntaskdiff "`discerntaskdiff'"
latex_write \discerntaskdiffse "`discerntaskdiffse'"
latex_write \discerntaskdiffdec "`discerntaskdiffdec'"

** Create CDF of time taken by task type
preserve
drop if q_time > 100
cdfplot q_time, by(tasktype) scheme(s1color) opt2(lp(solid dash dot))legend(rows(3))
graph export `"$figures/Experiment 3/CDF_drop_more_than_100_sec.pdf"', replace
restore

drop if q_time > 100

** Create binscatter with same axis as CDF
foreach x of numlist 1/3 {
	preserve
	binscatter q_correct q_time if tasktype == `x', ///
	linetype(none) nquantiles(15) savedata(task`x') replace
	clear
	do task`x'
	save task`x', replace
	restore
	
	append using task`x', gen(task`x')
	
	cap rm task`x'.csv
	cap rm task`x'.do
	cap rm task`x'.dta
}

twoway (scatter q_correct q_time if task1 == 1, color(dknavy)) ///
	(scatter q_correct q_time if task2 == 1, color(maroon))  ///
	(scatter q_correct q_time if task3 == 1, color(dkgreen)), ///
	xtitle("Time Spent on Task in Seconds") ytitle("Likelihood Task is Answered Accurately") ///
	xlabel(0(20)100) ylabel(0.5(0.1)1) ///
	legend(order(1 "60% or 40% Correct, 100 Equations (Baseline)" ///
	2 "60% or 40% Correct, 10 Equations (Easy, Length Arm)" ///
	3 "95% or 5% Correct, 100 Equations (Easy, Discernibility Arm)") rows(3)) ///
	scheme(s1color)

graph export `"$figures/Experiment 3/binscatter_overlaid.pdf"', replace
